/* Capstone Disassembly Engine, http://www.capstone-engine.org */
/* By Nguyen Anh Quynh <aquynh@gmail.com>, 2013-2022, */
/*    Rot127 <unisono@quyllur.org> 2022-2023 */
/* Automatically generated file by Capstone's LLVM TableGen Disassembler Backend. */

/* LLVM-commit: <commit> */
/* LLVM-tag: <tag> */

/* Do not edit. */

/* Capstone's LLVM TableGen Backends: */
/* https://github.com/capstone-engine/llvm-capstone */

#ifdef GET_INSTRINFO_ENUM
#undef GET_INSTRINFO_ENUM

  enum {
    TRICORE_PHI	= 0,
    TRICORE_INLINEASM	= 1,
    TRICORE_INLINEASM_BR	= 2,
    TRICORE_CFI_INSTRUCTION	= 3,
    TRICORE_EH_LABEL	= 4,
    TRICORE_GC_LABEL	= 5,
    TRICORE_ANNOTATION_LABEL	= 6,
    TRICORE_KILL	= 7,
    TRICORE_EXTRACT_SUBREG	= 8,
    TRICORE_INSERT_SUBREG	= 9,
    TRICORE_IMPLICIT_DEF	= 10,
    TRICORE_SUBREG_TO_REG	= 11,
    TRICORE_COPY_TO_REGCLASS	= 12,
    TRICORE_DBG_VALUE	= 13,
    TRICORE_DBG_VALUE_LIST	= 14,
    TRICORE_DBG_INSTR_REF	= 15,
    TRICORE_DBG_PHI	= 16,
    TRICORE_DBG_LABEL	= 17,
    TRICORE_REG_SEQUENCE	= 18,
    TRICORE_COPY	= 19,
    TRICORE_BUNDLE	= 20,
    TRICORE_LIFETIME_START	= 21,
    TRICORE_LIFETIME_END	= 22,
    TRICORE_PSEUDO_PROBE	= 23,
    TRICORE_ARITH_FENCE	= 24,
    TRICORE_STACKMAP	= 25,
    TRICORE_FENTRY_CALL	= 26,
    TRICORE_PATCHPOINT	= 27,
    TRICORE_LOAD_STACK_GUARD	= 28,
    TRICORE_PREALLOCATED_SETUP	= 29,
    TRICORE_PREALLOCATED_ARG	= 30,
    TRICORE_STATEPOINT	= 31,
    TRICORE_LOCAL_ESCAPE	= 32,
    TRICORE_FAULTING_OP	= 33,
    TRICORE_PATCHABLE_OP	= 34,
    TRICORE_PATCHABLE_FUNCTION_ENTER	= 35,
    TRICORE_PATCHABLE_RET	= 36,
    TRICORE_PATCHABLE_FUNCTION_EXIT	= 37,
    TRICORE_PATCHABLE_TAIL_CALL	= 38,
    TRICORE_PATCHABLE_EVENT_CALL	= 39,
    TRICORE_PATCHABLE_TYPED_EVENT_CALL	= 40,
    TRICORE_ICALL_BRANCH_FUNNEL	= 41,
    TRICORE_MEMBARRIER	= 42,
    TRICORE_G_ASSERT_SEXT	= 43,
    TRICORE_G_ASSERT_ZEXT	= 44,
    TRICORE_G_ASSERT_ALIGN	= 45,
    TRICORE_G_ADD	= 46,
    TRICORE_G_SUB	= 47,
    TRICORE_G_MUL	= 48,
    TRICORE_G_SDIV	= 49,
    TRICORE_G_UDIV	= 50,
    TRICORE_G_SREM	= 51,
    TRICORE_G_UREM	= 52,
    TRICORE_G_SDIVREM	= 53,
    TRICORE_G_UDIVREM	= 54,
    TRICORE_G_AND	= 55,
    TRICORE_G_OR	= 56,
    TRICORE_G_XOR	= 57,
    TRICORE_G_IMPLICIT_DEF	= 58,
    TRICORE_G_PHI	= 59,
    TRICORE_G_FRAME_INDEX	= 60,
    TRICORE_G_GLOBAL_VALUE	= 61,
    TRICORE_G_EXTRACT	= 62,
    TRICORE_G_UNMERGE_VALUES	= 63,
    TRICORE_G_INSERT	= 64,
    TRICORE_G_MERGE_VALUES	= 65,
    TRICORE_G_BUILD_VECTOR	= 66,
    TRICORE_G_BUILD_VECTOR_TRUNC	= 67,
    TRICORE_G_CONCAT_VECTORS	= 68,
    TRICORE_G_PTRTOINT	= 69,
    TRICORE_G_INTTOPTR	= 70,
    TRICORE_G_BITCAST	= 71,
    TRICORE_G_FREEZE	= 72,
    TRICORE_G_INTRINSIC_FPTRUNC_ROUND	= 73,
    TRICORE_G_INTRINSIC_TRUNC	= 74,
    TRICORE_G_INTRINSIC_ROUND	= 75,
    TRICORE_G_INTRINSIC_LRINT	= 76,
    TRICORE_G_INTRINSIC_ROUNDEVEN	= 77,
    TRICORE_G_READCYCLECOUNTER	= 78,
    TRICORE_G_LOAD	= 79,
    TRICORE_G_SEXTLOAD	= 80,
    TRICORE_G_ZEXTLOAD	= 81,
    TRICORE_G_INDEXED_LOAD	= 82,
    TRICORE_G_INDEXED_SEXTLOAD	= 83,
    TRICORE_G_INDEXED_ZEXTLOAD	= 84,
    TRICORE_G_STORE	= 85,
    TRICORE_G_INDEXED_STORE	= 86,
    TRICORE_G_ATOMIC_CMPXCHG_WITH_SUCCESS	= 87,
    TRICORE_G_ATOMIC_CMPXCHG	= 88,
    TRICORE_G_ATOMICRMW_XCHG	= 89,
    TRICORE_G_ATOMICRMW_ADD	= 90,
    TRICORE_G_ATOMICRMW_SUB	= 91,
    TRICORE_G_ATOMICRMW_AND	= 92,
    TRICORE_G_ATOMICRMW_NAND	= 93,
    TRICORE_G_ATOMICRMW_OR	= 94,
    TRICORE_G_ATOMICRMW_XOR	= 95,
    TRICORE_G_ATOMICRMW_MAX	= 96,
    TRICORE_G_ATOMICRMW_MIN	= 97,
    TRICORE_G_ATOMICRMW_UMAX	= 98,
    TRICORE_G_ATOMICRMW_UMIN	= 99,
    TRICORE_G_ATOMICRMW_FADD	= 100,
    TRICORE_G_ATOMICRMW_FSUB	= 101,
    TRICORE_G_ATOMICRMW_FMAX	= 102,
    TRICORE_G_ATOMICRMW_FMIN	= 103,
    TRICORE_G_ATOMICRMW_UINC_WRAP	= 104,
    TRICORE_G_ATOMICRMW_UDEC_WRAP	= 105,
    TRICORE_G_FENCE	= 106,
    TRICORE_G_BRCOND	= 107,
    TRICORE_G_BRINDIRECT	= 108,
    TRICORE_G_INVOKE_REGION_START	= 109,
    TRICORE_G_INTRINSIC	= 110,
    TRICORE_G_INTRINSIC_W_SIDE_EFFECTS	= 111,
    TRICORE_G_ANYEXT	= 112,
    TRICORE_G_TRUNC	= 113,
    TRICORE_G_CONSTANT	= 114,
    TRICORE_G_FCONSTANT	= 115,
    TRICORE_G_VASTART	= 116,
    TRICORE_G_VAARG	= 117,
    TRICORE_G_SEXT	= 118,
    TRICORE_G_SEXT_INREG	= 119,
    TRICORE_G_ZEXT	= 120,
    TRICORE_G_SHL	= 121,
    TRICORE_G_LSHR	= 122,
    TRICORE_G_ASHR	= 123,
    TRICORE_G_FSHL	= 124,
    TRICORE_G_FSHR	= 125,
    TRICORE_G_ROTR	= 126,
    TRICORE_G_ROTL	= 127,
    TRICORE_G_ICMP	= 128,
    TRICORE_G_FCMP	= 129,
    TRICORE_G_SELECT	= 130,
    TRICORE_G_UADDO	= 131,
    TRICORE_G_UADDE	= 132,
    TRICORE_G_USUBO	= 133,
    TRICORE_G_USUBE	= 134,
    TRICORE_G_SADDO	= 135,
    TRICORE_G_SADDE	= 136,
    TRICORE_G_SSUBO	= 137,
    TRICORE_G_SSUBE	= 138,
    TRICORE_G_UMULO	= 139,
    TRICORE_G_SMULO	= 140,
    TRICORE_G_UMULH	= 141,
    TRICORE_G_SMULH	= 142,
    TRICORE_G_UADDSAT	= 143,
    TRICORE_G_SADDSAT	= 144,
    TRICORE_G_USUBSAT	= 145,
    TRICORE_G_SSUBSAT	= 146,
    TRICORE_G_USHLSAT	= 147,
    TRICORE_G_SSHLSAT	= 148,
    TRICORE_G_SMULFIX	= 149,
    TRICORE_G_UMULFIX	= 150,
    TRICORE_G_SMULFIXSAT	= 151,
    TRICORE_G_UMULFIXSAT	= 152,
    TRICORE_G_SDIVFIX	= 153,
    TRICORE_G_UDIVFIX	= 154,
    TRICORE_G_SDIVFIXSAT	= 155,
    TRICORE_G_UDIVFIXSAT	= 156,
    TRICORE_G_FADD	= 157,
    TRICORE_G_FSUB	= 158,
    TRICORE_G_FMUL	= 159,
    TRICORE_G_FMA	= 160,
    TRICORE_G_FMAD	= 161,
    TRICORE_G_FDIV	= 162,
    TRICORE_G_FREM	= 163,
    TRICORE_G_FPOW	= 164,
    TRICORE_G_FPOWI	= 165,
    TRICORE_G_FEXP	= 166,
    TRICORE_G_FEXP2	= 167,
    TRICORE_G_FLOG	= 168,
    TRICORE_G_FLOG2	= 169,
    TRICORE_G_FLOG10	= 170,
    TRICORE_G_FNEG	= 171,
    TRICORE_G_FPEXT	= 172,
    TRICORE_G_FPTRUNC	= 173,
    TRICORE_G_FPTOSI	= 174,
    TRICORE_G_FPTOUI	= 175,
    TRICORE_G_SITOFP	= 176,
    TRICORE_G_UITOFP	= 177,
    TRICORE_G_FABS	= 178,
    TRICORE_G_FCOPYSIGN	= 179,
    TRICORE_G_IS_FPCLASS	= 180,
    TRICORE_G_FCANONICALIZE	= 181,
    TRICORE_G_FMINNUM	= 182,
    TRICORE_G_FMAXNUM	= 183,
    TRICORE_G_FMINNUM_IEEE	= 184,
    TRICORE_G_FMAXNUM_IEEE	= 185,
    TRICORE_G_FMINIMUM	= 186,
    TRICORE_G_FMAXIMUM	= 187,
    TRICORE_G_PTR_ADD	= 188,
    TRICORE_G_PTRMASK	= 189,
    TRICORE_G_SMIN	= 190,
    TRICORE_G_SMAX	= 191,
    TRICORE_G_UMIN	= 192,
    TRICORE_G_UMAX	= 193,
    TRICORE_G_ABS	= 194,
    TRICORE_G_LROUND	= 195,
    TRICORE_G_LLROUND	= 196,
    TRICORE_G_BR	= 197,
    TRICORE_G_BRJT	= 198,
    TRICORE_G_INSERT_VECTOR_ELT	= 199,
    TRICORE_G_EXTRACT_VECTOR_ELT	= 200,
    TRICORE_G_SHUFFLE_VECTOR	= 201,
    TRICORE_G_CTTZ	= 202,
    TRICORE_G_CTTZ_ZERO_UNDEF	= 203,
    TRICORE_G_CTLZ	= 204,
    TRICORE_G_CTLZ_ZERO_UNDEF	= 205,
    TRICORE_G_CTPOP	= 206,
    TRICORE_G_BSWAP	= 207,
    TRICORE_G_BITREVERSE	= 208,
    TRICORE_G_FCEIL	= 209,
    TRICORE_G_FCOS	= 210,
    TRICORE_G_FSIN	= 211,
    TRICORE_G_FSQRT	= 212,
    TRICORE_G_FFLOOR	= 213,
    TRICORE_G_FRINT	= 214,
    TRICORE_G_FNEARBYINT	= 215,
    TRICORE_G_ADDRSPACE_CAST	= 216,
    TRICORE_G_BLOCK_ADDR	= 217,
    TRICORE_G_JUMP_TABLE	= 218,
    TRICORE_G_DYN_STACKALLOC	= 219,
    TRICORE_G_STRICT_FADD	= 220,
    TRICORE_G_STRICT_FSUB	= 221,
    TRICORE_G_STRICT_FMUL	= 222,
    TRICORE_G_STRICT_FDIV	= 223,
    TRICORE_G_STRICT_FREM	= 224,
    TRICORE_G_STRICT_FMA	= 225,
    TRICORE_G_STRICT_FSQRT	= 226,
    TRICORE_G_READ_REGISTER	= 227,
    TRICORE_G_WRITE_REGISTER	= 228,
    TRICORE_G_MEMCPY	= 229,
    TRICORE_G_MEMCPY_INLINE	= 230,
    TRICORE_G_MEMMOVE	= 231,
    TRICORE_G_MEMSET	= 232,
    TRICORE_G_BZERO	= 233,
    TRICORE_G_VECREDUCE_SEQ_FADD	= 234,
    TRICORE_G_VECREDUCE_SEQ_FMUL	= 235,
    TRICORE_G_VECREDUCE_FADD	= 236,
    TRICORE_G_VECREDUCE_FMUL	= 237,
    TRICORE_G_VECREDUCE_FMAX	= 238,
    TRICORE_G_VECREDUCE_FMIN	= 239,
    TRICORE_G_VECREDUCE_ADD	= 240,
    TRICORE_G_VECREDUCE_MUL	= 241,
    TRICORE_G_VECREDUCE_AND	= 242,
    TRICORE_G_VECREDUCE_OR	= 243,
    TRICORE_G_VECREDUCE_XOR	= 244,
    TRICORE_G_VECREDUCE_SMAX	= 245,
    TRICORE_G_VECREDUCE_SMIN	= 246,
    TRICORE_G_VECREDUCE_UMAX	= 247,
    TRICORE_G_VECREDUCE_UMIN	= 248,
    TRICORE_G_SBFX	= 249,
    TRICORE_G_UBFX	= 250,
    TRICORE_ABSDIFS_B_rr_v110	= 251,
    TRICORE_ABSDIFS_H_rr	= 252,
    TRICORE_ABSDIFS_rc	= 253,
    TRICORE_ABSDIFS_rr	= 254,
    TRICORE_ABSDIF_B_rr	= 255,
    TRICORE_ABSDIF_H_rr	= 256,
    TRICORE_ABSDIF_rc	= 257,
    TRICORE_ABSDIF_rr	= 258,
    TRICORE_ABSS_B_rr_v110	= 259,
    TRICORE_ABSS_H_rr	= 260,
    TRICORE_ABSS_rr	= 261,
    TRICORE_ABS_B_rr	= 262,
    TRICORE_ABS_H_rr	= 263,
    TRICORE_ABS_rr	= 264,
    TRICORE_ADDC_rc	= 265,
    TRICORE_ADDC_rr	= 266,
    TRICORE_ADDIH_A_rlc	= 267,
    TRICORE_ADDIH_rlc	= 268,
    TRICORE_ADDI_rlc	= 269,
    TRICORE_ADDSC_AT_rr	= 270,
    TRICORE_ADDSC_AT_rr_v110	= 271,
    TRICORE_ADDSC_A_rr	= 272,
    TRICORE_ADDSC_A_rr_v110	= 273,
    TRICORE_ADDSC_A_srrs	= 274,
    TRICORE_ADDSC_A_srrs_v110	= 275,
    TRICORE_ADDS_BU_rr_v110	= 276,
    TRICORE_ADDS_B_rr	= 277,
    TRICORE_ADDS_H	= 278,
    TRICORE_ADDS_HU	= 279,
    TRICORE_ADDS_U	= 280,
    TRICORE_ADDS_U_rc	= 281,
    TRICORE_ADDS_rc	= 282,
    TRICORE_ADDS_rr	= 283,
    TRICORE_ADDS_srr	= 284,
    TRICORE_ADDX_rc	= 285,
    TRICORE_ADDX_rr	= 286,
    TRICORE_ADD_A_rr	= 287,
    TRICORE_ADD_A_src	= 288,
    TRICORE_ADD_A_srr	= 289,
    TRICORE_ADD_B_rr	= 290,
    TRICORE_ADD_F_rrr	= 291,
    TRICORE_ADD_H_rr	= 292,
    TRICORE_ADD_rc	= 293,
    TRICORE_ADD_rr	= 294,
    TRICORE_ADD_src	= 295,
    TRICORE_ADD_src_15a	= 296,
    TRICORE_ADD_src_a15	= 297,
    TRICORE_ADD_srr	= 298,
    TRICORE_ADD_srr_15a	= 299,
    TRICORE_ADD_srr_a15	= 300,
    TRICORE_ANDN_T	= 301,
    TRICORE_ANDN_rc	= 302,
    TRICORE_ANDN_rr	= 303,
    TRICORE_AND_ANDN_T	= 304,
    TRICORE_AND_AND_T	= 305,
    TRICORE_AND_EQ_rc	= 306,
    TRICORE_AND_EQ_rr	= 307,
    TRICORE_AND_GE_U_rc	= 308,
    TRICORE_AND_GE_U_rr	= 309,
    TRICORE_AND_GE_rc	= 310,
    TRICORE_AND_GE_rr	= 311,
    TRICORE_AND_LT_U_rc	= 312,
    TRICORE_AND_LT_U_rr	= 313,
    TRICORE_AND_LT_rc	= 314,
    TRICORE_AND_LT_rr	= 315,
    TRICORE_AND_NE_rc	= 316,
    TRICORE_AND_NE_rr	= 317,
    TRICORE_AND_NOR_T	= 318,
    TRICORE_AND_OR_T	= 319,
    TRICORE_AND_T	= 320,
    TRICORE_AND_rc	= 321,
    TRICORE_AND_rr	= 322,
    TRICORE_AND_sc	= 323,
    TRICORE_AND_sc_v110	= 324,
    TRICORE_AND_srr	= 325,
    TRICORE_AND_srr_v110	= 326,
    TRICORE_BISR_rc	= 327,
    TRICORE_BISR_rc_v161	= 328,
    TRICORE_BISR_sc	= 329,
    TRICORE_BISR_sc_v110	= 330,
    TRICORE_BMERGAE_rr_v110	= 331,
    TRICORE_BMERGE_rr	= 332,
    TRICORE_BSPLIT_rr	= 333,
    TRICORE_BSPLIT_rr_v110	= 334,
    TRICORE_CACHEA_I_bo_bso	= 335,
    TRICORE_CACHEA_I_bo_c	= 336,
    TRICORE_CACHEA_I_bo_pos	= 337,
    TRICORE_CACHEA_I_bo_pre	= 338,
    TRICORE_CACHEA_I_bo_r	= 339,
    TRICORE_CACHEA_WI_bo_bso	= 340,
    TRICORE_CACHEA_WI_bo_c	= 341,
    TRICORE_CACHEA_WI_bo_pos	= 342,
    TRICORE_CACHEA_WI_bo_pre	= 343,
    TRICORE_CACHEA_WI_bo_r	= 344,
    TRICORE_CACHEA_W_bo_bso	= 345,
    TRICORE_CACHEA_W_bo_c	= 346,
    TRICORE_CACHEA_W_bo_pos	= 347,
    TRICORE_CACHEA_W_bo_pre	= 348,
    TRICORE_CACHEA_W_bo_r	= 349,
    TRICORE_CACHEI_I_bo_bso	= 350,
    TRICORE_CACHEI_I_bo_pos	= 351,
    TRICORE_CACHEI_I_bo_pre	= 352,
    TRICORE_CACHEI_WI_bo_bso	= 353,
    TRICORE_CACHEI_WI_bo_pos	= 354,
    TRICORE_CACHEI_WI_bo_pre	= 355,
    TRICORE_CACHEI_W_bo_bso	= 356,
    TRICORE_CACHEI_W_bo_pos	= 357,
    TRICORE_CACHEI_W_bo_pre	= 358,
    TRICORE_CADDN_A_rcr_v110	= 359,
    TRICORE_CADDN_A_rrr_v110	= 360,
    TRICORE_CADDN_rcr	= 361,
    TRICORE_CADDN_rrr	= 362,
    TRICORE_CADDN_src	= 363,
    TRICORE_CADDN_srr_v110	= 364,
    TRICORE_CADD_A_rcr_v110	= 365,
    TRICORE_CADD_A_rrr_v110	= 366,
    TRICORE_CADD_rcr	= 367,
    TRICORE_CADD_rrr	= 368,
    TRICORE_CADD_src	= 369,
    TRICORE_CADD_srr_v110	= 370,
    TRICORE_CALLA_b	= 371,
    TRICORE_CALLI_rr	= 372,
    TRICORE_CALLI_rr_v110	= 373,
    TRICORE_CALL_b	= 374,
    TRICORE_CALL_sb	= 375,
    TRICORE_CLO_B_rr_v110	= 376,
    TRICORE_CLO_H_rr	= 377,
    TRICORE_CLO_rr	= 378,
    TRICORE_CLS_B_rr_v110	= 379,
    TRICORE_CLS_H_rr	= 380,
    TRICORE_CLS_rr	= 381,
    TRICORE_CLZ_B_rr_v110	= 382,
    TRICORE_CLZ_H_rr	= 383,
    TRICORE_CLZ_rr	= 384,
    TRICORE_CMOVN_src	= 385,
    TRICORE_CMOVN_srr	= 386,
    TRICORE_CMOV_src	= 387,
    TRICORE_CMOV_srr	= 388,
    TRICORE_CMPSWAP_W_bo_bso	= 389,
    TRICORE_CMPSWAP_W_bo_c	= 390,
    TRICORE_CMPSWAP_W_bo_pos	= 391,
    TRICORE_CMPSWAP_W_bo_pre	= 392,
    TRICORE_CMPSWAP_W_bo_r	= 393,
    TRICORE_CMP_F_rr	= 394,
    TRICORE_CRC32B_W_rr	= 395,
    TRICORE_CRC32L_W_rr	= 396,
    TRICORE_CRC32_B_rr	= 397,
    TRICORE_CRCN_rrr	= 398,
    TRICORE_CSUBN_A__rrr_v110	= 399,
    TRICORE_CSUBN_rrr	= 400,
    TRICORE_CSUB_A__rrr_v110	= 401,
    TRICORE_CSUB_rrr	= 402,
    TRICORE_DEBUG_sr	= 403,
    TRICORE_DEBUG_sys	= 404,
    TRICORE_DEXTR_rrpw	= 405,
    TRICORE_DEXTR_rrrr	= 406,
    TRICORE_DIFSC_A_rr_v110	= 407,
    TRICORE_DISABLE_sys	= 408,
    TRICORE_DISABLE_sys_1	= 409,
    TRICORE_DIV_F_rr	= 410,
    TRICORE_DIV_U_rr	= 411,
    TRICORE_DIV_rr	= 412,
    TRICORE_DSYNC_sys	= 413,
    TRICORE_DVADJ_rrr	= 414,
    TRICORE_DVADJ_rrr_v110	= 415,
    TRICORE_DVADJ_srr_v110	= 416,
    TRICORE_DVINIT_BU_rr	= 417,
    TRICORE_DVINIT_BU_rr_v110	= 418,
    TRICORE_DVINIT_B_rr	= 419,
    TRICORE_DVINIT_B_rr_v110	= 420,
    TRICORE_DVINIT_HU_rr	= 421,
    TRICORE_DVINIT_HU_rr_v110	= 422,
    TRICORE_DVINIT_H_rr	= 423,
    TRICORE_DVINIT_H_rr_v110	= 424,
    TRICORE_DVINIT_U_rr	= 425,
    TRICORE_DVINIT_U_rr_v110	= 426,
    TRICORE_DVINIT_rr	= 427,
    TRICORE_DVINIT_rr_v110	= 428,
    TRICORE_DVSTEP_U_rrr	= 429,
    TRICORE_DVSTEP_U_rrrv110	= 430,
    TRICORE_DVSTEP_Uv110	= 431,
    TRICORE_DVSTEP_rrr	= 432,
    TRICORE_DVSTEP_rrrv110	= 433,
    TRICORE_DVSTEPv110	= 434,
    TRICORE_ENABLE_sys	= 435,
    TRICORE_EQANY_B_rc	= 436,
    TRICORE_EQANY_B_rr	= 437,
    TRICORE_EQANY_H_rc	= 438,
    TRICORE_EQANY_H_rr	= 439,
    TRICORE_EQZ_A_rr	= 440,
    TRICORE_EQ_A_rr	= 441,
    TRICORE_EQ_B_rr	= 442,
    TRICORE_EQ_H_rr	= 443,
    TRICORE_EQ_W_rr	= 444,
    TRICORE_EQ_rc	= 445,
    TRICORE_EQ_rr	= 446,
    TRICORE_EQ_src	= 447,
    TRICORE_EQ_srr	= 448,
    TRICORE_EXTR_U_rrpw	= 449,
    TRICORE_EXTR_U_rrrr	= 450,
    TRICORE_EXTR_U_rrrw	= 451,
    TRICORE_EXTR_rrpw	= 452,
    TRICORE_EXTR_rrrr	= 453,
    TRICORE_EXTR_rrrw	= 454,
    TRICORE_FCALLA_b	= 455,
    TRICORE_FCALLA_i	= 456,
    TRICORE_FCALL_b	= 457,
    TRICORE_FRET_sr	= 458,
    TRICORE_FRET_sys	= 459,
    TRICORE_FTOHP_rr	= 460,
    TRICORE_FTOIZ_rr	= 461,
    TRICORE_FTOI_rr	= 462,
    TRICORE_FTOQ31Z_rr	= 463,
    TRICORE_FTOQ31_rr	= 464,
    TRICORE_FTOUZ_rr	= 465,
    TRICORE_FTOU_rr	= 466,
    TRICORE_GE_A_rr	= 467,
    TRICORE_GE_U_rc	= 468,
    TRICORE_GE_U_rr	= 469,
    TRICORE_GE_rc	= 470,
    TRICORE_GE_rr	= 471,
    TRICORE_HPTOF_rr	= 472,
    TRICORE_IMASK_rcpw	= 473,
    TRICORE_IMASK_rcrw	= 474,
    TRICORE_IMASK_rrpw	= 475,
    TRICORE_IMASK_rrrw	= 476,
    TRICORE_INSERT_rcpw	= 477,
    TRICORE_INSERT_rcrr	= 478,
    TRICORE_INSERT_rcrw	= 479,
    TRICORE_INSERT_rrpw	= 480,
    TRICORE_INSERT_rrrr	= 481,
    TRICORE_INSERT_rrrw	= 482,
    TRICORE_INSN_T	= 483,
    TRICORE_INS_T	= 484,
    TRICORE_ISYNC_sys	= 485,
    TRICORE_ITOF_rr	= 486,
    TRICORE_IXMAX_U_rrr	= 487,
    TRICORE_IXMAX_rrr	= 488,
    TRICORE_IXMIN_U_rrr	= 489,
    TRICORE_IXMIN_rrr	= 490,
    TRICORE_JA_b	= 491,
    TRICORE_JEQ_A_brr	= 492,
    TRICORE_JEQ_brc	= 493,
    TRICORE_JEQ_brr	= 494,
    TRICORE_JEQ_sbc1	= 495,
    TRICORE_JEQ_sbc2	= 496,
    TRICORE_JEQ_sbc_v110	= 497,
    TRICORE_JEQ_sbr1	= 498,
    TRICORE_JEQ_sbr2	= 499,
    TRICORE_JEQ_sbr_v110	= 500,
    TRICORE_JGEZ_sbr	= 501,
    TRICORE_JGEZ_sbr_v110	= 502,
    TRICORE_JGE_U_brc	= 503,
    TRICORE_JGE_U_brr	= 504,
    TRICORE_JGE_brc	= 505,
    TRICORE_JGE_brr	= 506,
    TRICORE_JGTZ_sbr	= 507,
    TRICORE_JGTZ_sbr_v110	= 508,
    TRICORE_JI_rr	= 509,
    TRICORE_JI_rr_v110	= 510,
    TRICORE_JI_sbr_v110	= 511,
    TRICORE_JI_sr	= 512,
    TRICORE_JLA_b	= 513,
    TRICORE_JLEZ_sbr	= 514,
    TRICORE_JLEZ_sbr_v110	= 515,
    TRICORE_JLI_rr	= 516,
    TRICORE_JLI_rr_v110	= 517,
    TRICORE_JLTZ_sbr	= 518,
    TRICORE_JLTZ_sbr_v110	= 519,
    TRICORE_JLT_U_brc	= 520,
    TRICORE_JLT_U_brr	= 521,
    TRICORE_JLT_brc	= 522,
    TRICORE_JLT_brr	= 523,
    TRICORE_JL_b	= 524,
    TRICORE_JNED_brc	= 525,
    TRICORE_JNED_brr	= 526,
    TRICORE_JNEI_brc	= 527,
    TRICORE_JNEI_brr	= 528,
    TRICORE_JNE_A_brr	= 529,
    TRICORE_JNE_brc	= 530,
    TRICORE_JNE_brr	= 531,
    TRICORE_JNE_sbc1	= 532,
    TRICORE_JNE_sbc2	= 533,
    TRICORE_JNE_sbc_v110	= 534,
    TRICORE_JNE_sbr1	= 535,
    TRICORE_JNE_sbr2	= 536,
    TRICORE_JNE_sbr_v110	= 537,
    TRICORE_JNZ_A_brr	= 538,
    TRICORE_JNZ_A_sbr	= 539,
    TRICORE_JNZ_T_brn	= 540,
    TRICORE_JNZ_T_sbrn	= 541,
    TRICORE_JNZ_T_sbrn_v110	= 542,
    TRICORE_JNZ_sb	= 543,
    TRICORE_JNZ_sb_v110	= 544,
    TRICORE_JNZ_sbr	= 545,
    TRICORE_JNZ_sbr_v110	= 546,
    TRICORE_JZ_A_brr	= 547,
    TRICORE_JZ_A_sbr	= 548,
    TRICORE_JZ_T_brn	= 549,
    TRICORE_JZ_T_sbrn	= 550,
    TRICORE_JZ_T_sbrn_v110	= 551,
    TRICORE_JZ_sb	= 552,
    TRICORE_JZ_sb_v110	= 553,
    TRICORE_JZ_sbr	= 554,
    TRICORE_JZ_sbr_v110	= 555,
    TRICORE_J_b	= 556,
    TRICORE_J_sb	= 557,
    TRICORE_J_sb_v110	= 558,
    TRICORE_LDLCX_abs	= 559,
    TRICORE_LDLCX_bo_bso	= 560,
    TRICORE_LDMST_abs	= 561,
    TRICORE_LDMST_bo_bso	= 562,
    TRICORE_LDMST_bo_c	= 563,
    TRICORE_LDMST_bo_pos	= 564,
    TRICORE_LDMST_bo_pre	= 565,
    TRICORE_LDMST_bo_r	= 566,
    TRICORE_LDUCX_abs	= 567,
    TRICORE_LDUCX_bo_bso	= 568,
    TRICORE_LD_A_abs	= 569,
    TRICORE_LD_A_bo_bso	= 570,
    TRICORE_LD_A_bo_c	= 571,
    TRICORE_LD_A_bo_pos	= 572,
    TRICORE_LD_A_bo_pre	= 573,
    TRICORE_LD_A_bo_r	= 574,
    TRICORE_LD_A_bol	= 575,
    TRICORE_LD_A_sc	= 576,
    TRICORE_LD_A_slr	= 577,
    TRICORE_LD_A_slr_post	= 578,
    TRICORE_LD_A_slr_post_v110	= 579,
    TRICORE_LD_A_slr_v110	= 580,
    TRICORE_LD_A_slro	= 581,
    TRICORE_LD_A_slro_v110	= 582,
    TRICORE_LD_A_sro	= 583,
    TRICORE_LD_A_sro_v110	= 584,
    TRICORE_LD_BU_abs	= 585,
    TRICORE_LD_BU_bo_bso	= 586,
    TRICORE_LD_BU_bo_c	= 587,
    TRICORE_LD_BU_bo_pos	= 588,
    TRICORE_LD_BU_bo_pre	= 589,
    TRICORE_LD_BU_bo_r	= 590,
    TRICORE_LD_BU_bol	= 591,
    TRICORE_LD_BU_slr	= 592,
    TRICORE_LD_BU_slr_post	= 593,
    TRICORE_LD_BU_slr_post_v110	= 594,
    TRICORE_LD_BU_slr_v110	= 595,
    TRICORE_LD_BU_slro	= 596,
    TRICORE_LD_BU_slro_v110	= 597,
    TRICORE_LD_BU_sro	= 598,
    TRICORE_LD_BU_sro_v110	= 599,
    TRICORE_LD_B_abs	= 600,
    TRICORE_LD_B_bo_bso	= 601,
    TRICORE_LD_B_bo_c	= 602,
    TRICORE_LD_B_bo_pos	= 603,
    TRICORE_LD_B_bo_pre	= 604,
    TRICORE_LD_B_bo_r	= 605,
    TRICORE_LD_B_bol	= 606,
    TRICORE_LD_B_slr_post_v110	= 607,
    TRICORE_LD_B_slr_v110	= 608,
    TRICORE_LD_B_slro_v110	= 609,
    TRICORE_LD_B_sro_v110	= 610,
    TRICORE_LD_DA_abs	= 611,
    TRICORE_LD_DA_bo_bso	= 612,
    TRICORE_LD_DA_bo_c	= 613,
    TRICORE_LD_DA_bo_pos	= 614,
    TRICORE_LD_DA_bo_pre	= 615,
    TRICORE_LD_DA_bo_r	= 616,
    TRICORE_LD_D_abs	= 617,
    TRICORE_LD_D_bo_bso	= 618,
    TRICORE_LD_D_bo_c	= 619,
    TRICORE_LD_D_bo_pos	= 620,
    TRICORE_LD_D_bo_pre	= 621,
    TRICORE_LD_D_bo_r	= 622,
    TRICORE_LD_HU_abs	= 623,
    TRICORE_LD_HU_bo_bso	= 624,
    TRICORE_LD_HU_bo_c	= 625,
    TRICORE_LD_HU_bo_pos	= 626,
    TRICORE_LD_HU_bo_pre	= 627,
    TRICORE_LD_HU_bo_r	= 628,
    TRICORE_LD_HU_bol	= 629,
    TRICORE_LD_H_abs	= 630,
    TRICORE_LD_H_bo_bso	= 631,
    TRICORE_LD_H_bo_c	= 632,
    TRICORE_LD_H_bo_pos	= 633,
    TRICORE_LD_H_bo_pre	= 634,
    TRICORE_LD_H_bo_r	= 635,
    TRICORE_LD_H_bol	= 636,
    TRICORE_LD_H_slr	= 637,
    TRICORE_LD_H_slr_post	= 638,
    TRICORE_LD_H_slr_post_v110	= 639,
    TRICORE_LD_H_slr_v110	= 640,
    TRICORE_LD_H_slro	= 641,
    TRICORE_LD_H_slro_v110	= 642,
    TRICORE_LD_H_sro	= 643,
    TRICORE_LD_H_sro_v110	= 644,
    TRICORE_LD_Q_abs	= 645,
    TRICORE_LD_Q_bo_bso	= 646,
    TRICORE_LD_Q_bo_c	= 647,
    TRICORE_LD_Q_bo_pos	= 648,
    TRICORE_LD_Q_bo_pre	= 649,
    TRICORE_LD_Q_bo_r	= 650,
    TRICORE_LD_W_abs	= 651,
    TRICORE_LD_W_bo_bso	= 652,
    TRICORE_LD_W_bo_c	= 653,
    TRICORE_LD_W_bo_pos	= 654,
    TRICORE_LD_W_bo_pre	= 655,
    TRICORE_LD_W_bo_r	= 656,
    TRICORE_LD_W_bol	= 657,
    TRICORE_LD_W_sc	= 658,
    TRICORE_LD_W_slr	= 659,
    TRICORE_LD_W_slr_post	= 660,
    TRICORE_LD_W_slr_post_v110	= 661,
    TRICORE_LD_W_slr_v110	= 662,
    TRICORE_LD_W_slro	= 663,
    TRICORE_LD_W_slro_v110	= 664,
    TRICORE_LD_W_sro	= 665,
    TRICORE_LD_W_sro_v110	= 666,
    TRICORE_LEA_abs	= 667,
    TRICORE_LEA_bo_bso	= 668,
    TRICORE_LEA_bol	= 669,
    TRICORE_LHA_abs	= 670,
    TRICORE_LOOPU_brr	= 671,
    TRICORE_LOOP_brr	= 672,
    TRICORE_LOOP_sbr	= 673,
    TRICORE_LT_A_rr	= 674,
    TRICORE_LT_B	= 675,
    TRICORE_LT_BU	= 676,
    TRICORE_LT_H	= 677,
    TRICORE_LT_HU	= 678,
    TRICORE_LT_U_rc	= 679,
    TRICORE_LT_U_rr	= 680,
    TRICORE_LT_U_srcv110	= 681,
    TRICORE_LT_U_srrv110	= 682,
    TRICORE_LT_W	= 683,
    TRICORE_LT_WU	= 684,
    TRICORE_LT_rc	= 685,
    TRICORE_LT_rr	= 686,
    TRICORE_LT_src	= 687,
    TRICORE_LT_srr	= 688,
    TRICORE_MADDMS_H_rrr1_LL	= 689,
    TRICORE_MADDMS_H_rrr1_LU	= 690,
    TRICORE_MADDMS_H_rrr1_UL	= 691,
    TRICORE_MADDMS_H_rrr1_UU	= 692,
    TRICORE_MADDMS_U_rcr_v110	= 693,
    TRICORE_MADDMS_U_rrr2_v110	= 694,
    TRICORE_MADDMS_rcr_v110	= 695,
    TRICORE_MADDMS_rrr2_v110	= 696,
    TRICORE_MADDM_H_rrr1_LL	= 697,
    TRICORE_MADDM_H_rrr1_LU	= 698,
    TRICORE_MADDM_H_rrr1_UL	= 699,
    TRICORE_MADDM_H_rrr1_UU	= 700,
    TRICORE_MADDM_H_rrr1_v110	= 701,
    TRICORE_MADDM_Q_rrr1_v110	= 702,
    TRICORE_MADDM_U_rcr_v110	= 703,
    TRICORE_MADDM_U_rrr2_v110	= 704,
    TRICORE_MADDM_rcr_v110	= 705,
    TRICORE_MADDM_rrr2_v110	= 706,
    TRICORE_MADDRS_H_rrr1_LL	= 707,
    TRICORE_MADDRS_H_rrr1_LU	= 708,
    TRICORE_MADDRS_H_rrr1_UL	= 709,
    TRICORE_MADDRS_H_rrr1_UL_2	= 710,
    TRICORE_MADDRS_H_rrr1_UU	= 711,
    TRICORE_MADDRS_H_rrr1_v110	= 712,
    TRICORE_MADDRS_Q_rrr1_L_L	= 713,
    TRICORE_MADDRS_Q_rrr1_U_U	= 714,
    TRICORE_MADDRS_Q_rrr1_v110	= 715,
    TRICORE_MADDR_H_rrr1_LL	= 716,
    TRICORE_MADDR_H_rrr1_LU	= 717,
    TRICORE_MADDR_H_rrr1_UL	= 718,
    TRICORE_MADDR_H_rrr1_UL_2	= 719,
    TRICORE_MADDR_H_rrr1_UU	= 720,
    TRICORE_MADDR_H_rrr1_v110	= 721,
    TRICORE_MADDR_Q_rrr1_L_L	= 722,
    TRICORE_MADDR_Q_rrr1_U_U	= 723,
    TRICORE_MADDR_Q_rrr1_v110	= 724,
    TRICORE_MADDSUMS_H_rrr1_LL	= 725,
    TRICORE_MADDSUMS_H_rrr1_LU	= 726,
    TRICORE_MADDSUMS_H_rrr1_UL	= 727,
    TRICORE_MADDSUMS_H_rrr1_UU	= 728,
    TRICORE_MADDSUM_H_rrr1_LL	= 729,
    TRICORE_MADDSUM_H_rrr1_LU	= 730,
    TRICORE_MADDSUM_H_rrr1_UL	= 731,
    TRICORE_MADDSUM_H_rrr1_UU	= 732,
    TRICORE_MADDSURS_H_rrr1_LL	= 733,
    TRICORE_MADDSURS_H_rrr1_LU	= 734,
    TRICORE_MADDSURS_H_rrr1_UL	= 735,
    TRICORE_MADDSURS_H_rrr1_UU	= 736,
    TRICORE_MADDSUR_H_rrr1_LL	= 737,
    TRICORE_MADDSUR_H_rrr1_LU	= 738,
    TRICORE_MADDSUR_H_rrr1_UL	= 739,
    TRICORE_MADDSUR_H_rrr1_UU	= 740,
    TRICORE_MADDSUS_H_rrr1_LL	= 741,
    TRICORE_MADDSUS_H_rrr1_LU	= 742,
    TRICORE_MADDSUS_H_rrr1_UL	= 743,
    TRICORE_MADDSUS_H_rrr1_UU	= 744,
    TRICORE_MADDSU_H_rrr1_LL	= 745,
    TRICORE_MADDSU_H_rrr1_LU	= 746,
    TRICORE_MADDSU_H_rrr1_UL	= 747,
    TRICORE_MADDSU_H_rrr1_UU	= 748,
    TRICORE_MADDS_H_rrr1_LL	= 749,
    TRICORE_MADDS_H_rrr1_LU	= 750,
    TRICORE_MADDS_H_rrr1_UL	= 751,
    TRICORE_MADDS_H_rrr1_UU	= 752,
    TRICORE_MADDS_H_rrr1_v110	= 753,
    TRICORE_MADDS_Q_rrr1	= 754,
    TRICORE_MADDS_Q_rrr1_L	= 755,
    TRICORE_MADDS_Q_rrr1_L_L	= 756,
    TRICORE_MADDS_Q_rrr1_U	= 757,
    TRICORE_MADDS_Q_rrr1_UU2_v110	= 758,
    TRICORE_MADDS_Q_rrr1_U_U	= 759,
    TRICORE_MADDS_Q_rrr1_e	= 760,
    TRICORE_MADDS_Q_rrr1_e_L	= 761,
    TRICORE_MADDS_Q_rrr1_e_L_L	= 762,
    TRICORE_MADDS_Q_rrr1_e_U	= 763,
    TRICORE_MADDS_Q_rrr1_e_U_U	= 764,
    TRICORE_MADDS_U_rcr	= 765,
    TRICORE_MADDS_U_rcr_e	= 766,
    TRICORE_MADDS_U_rrr2	= 767,
    TRICORE_MADDS_U_rrr2_e	= 768,
    TRICORE_MADDS_rcr	= 769,
    TRICORE_MADDS_rcr_e	= 770,
    TRICORE_MADDS_rrr2	= 771,
    TRICORE_MADDS_rrr2_e	= 772,
    TRICORE_MADD_F_rrr	= 773,
    TRICORE_MADD_H_rrr1_LL	= 774,
    TRICORE_MADD_H_rrr1_LU	= 775,
    TRICORE_MADD_H_rrr1_UL	= 776,
    TRICORE_MADD_H_rrr1_UU	= 777,
    TRICORE_MADD_H_rrr1_v110	= 778,
    TRICORE_MADD_Q_rrr1	= 779,
    TRICORE_MADD_Q_rrr1_L	= 780,
    TRICORE_MADD_Q_rrr1_L_L	= 781,
    TRICORE_MADD_Q_rrr1_U	= 782,
    TRICORE_MADD_Q_rrr1_UU2_v110	= 783,
    TRICORE_MADD_Q_rrr1_U_U	= 784,
    TRICORE_MADD_Q_rrr1_e	= 785,
    TRICORE_MADD_Q_rrr1_e_L	= 786,
    TRICORE_MADD_Q_rrr1_e_L_L	= 787,
    TRICORE_MADD_Q_rrr1_e_U	= 788,
    TRICORE_MADD_Q_rrr1_e_U_U	= 789,
    TRICORE_MADD_U_rcr	= 790,
    TRICORE_MADD_U_rrr2	= 791,
    TRICORE_MADD_rcr	= 792,
    TRICORE_MADD_rcr_e	= 793,
    TRICORE_MADD_rrr2	= 794,
    TRICORE_MADD_rrr2_e	= 795,
    TRICORE_MAX_B	= 796,
    TRICORE_MAX_BU	= 797,
    TRICORE_MAX_H	= 798,
    TRICORE_MAX_HU	= 799,
    TRICORE_MAX_U_rc	= 800,
    TRICORE_MAX_U_rr	= 801,
    TRICORE_MAX_rc	= 802,
    TRICORE_MAX_rr	= 803,
    TRICORE_MFCR_rlc	= 804,
    TRICORE_MIN_B	= 805,
    TRICORE_MIN_BU	= 806,
    TRICORE_MIN_H	= 807,
    TRICORE_MIN_HU	= 808,
    TRICORE_MIN_U_rc	= 809,
    TRICORE_MIN_U_rr	= 810,
    TRICORE_MIN_rc	= 811,
    TRICORE_MIN_rr	= 812,
    TRICORE_MOVH_A_rlc	= 813,
    TRICORE_MOVH_rlc	= 814,
    TRICORE_MOVZ_A_sr	= 815,
    TRICORE_MOV_AA_rr	= 816,
    TRICORE_MOV_AA_srr_srr	= 817,
    TRICORE_MOV_AA_srr_srr_v110	= 818,
    TRICORE_MOV_A_rr	= 819,
    TRICORE_MOV_A_src	= 820,
    TRICORE_MOV_A_srr	= 821,
    TRICORE_MOV_A_srr_v110	= 822,
    TRICORE_MOV_D_rr	= 823,
    TRICORE_MOV_D_srr_srr	= 824,
    TRICORE_MOV_D_srr_srr_v110	= 825,
    TRICORE_MOV_U_rlc	= 826,
    TRICORE_MOV_rlc	= 827,
    TRICORE_MOV_rlc_e	= 828,
    TRICORE_MOV_rr	= 829,
    TRICORE_MOV_rr_e	= 830,
    TRICORE_MOV_rr_eab	= 831,
    TRICORE_MOV_sc	= 832,
    TRICORE_MOV_sc_v110	= 833,
    TRICORE_MOV_src	= 834,
    TRICORE_MOV_src_e	= 835,
    TRICORE_MOV_srr	= 836,
    TRICORE_MSUBADMS_H_rrr1_LL	= 837,
    TRICORE_MSUBADMS_H_rrr1_LU	= 838,
    TRICORE_MSUBADMS_H_rrr1_UL	= 839,
    TRICORE_MSUBADMS_H_rrr1_UU	= 840,
    TRICORE_MSUBADM_H_rrr1_LL	= 841,
    TRICORE_MSUBADM_H_rrr1_LU	= 842,
    TRICORE_MSUBADM_H_rrr1_UL	= 843,
    TRICORE_MSUBADM_H_rrr1_UU	= 844,
    TRICORE_MSUBADRS_H_rrr1_LL	= 845,
    TRICORE_MSUBADRS_H_rrr1_LU	= 846,
    TRICORE_MSUBADRS_H_rrr1_UL	= 847,
    TRICORE_MSUBADRS_H_rrr1_UU	= 848,
    TRICORE_MSUBADRS_H_rrr1_v110	= 849,
    TRICORE_MSUBADR_H_rrr1_LL	= 850,
    TRICORE_MSUBADR_H_rrr1_LU	= 851,
    TRICORE_MSUBADR_H_rrr1_UL	= 852,
    TRICORE_MSUBADR_H_rrr1_UU	= 853,
    TRICORE_MSUBADR_H_rrr1_v110	= 854,
    TRICORE_MSUBADS_H_rrr1_LL	= 855,
    TRICORE_MSUBADS_H_rrr1_LU	= 856,
    TRICORE_MSUBADS_H_rrr1_UL	= 857,
    TRICORE_MSUBADS_H_rrr1_UU	= 858,
    TRICORE_MSUBAD_H_rrr1_LL	= 859,
    TRICORE_MSUBAD_H_rrr1_LU	= 860,
    TRICORE_MSUBAD_H_rrr1_UL	= 861,
    TRICORE_MSUBAD_H_rrr1_UU	= 862,
    TRICORE_MSUBMS_H_rrr1_LL	= 863,
    TRICORE_MSUBMS_H_rrr1_LU	= 864,
    TRICORE_MSUBMS_H_rrr1_UL	= 865,
    TRICORE_MSUBMS_H_rrr1_UU	= 866,
    TRICORE_MSUBMS_U_rcrv110	= 867,
    TRICORE_MSUBMS_U_rrr2v110	= 868,
    TRICORE_MSUBMS_rcrv110	= 869,
    TRICORE_MSUBMS_rrr2v110	= 870,
    TRICORE_MSUBM_H_rrr1_LL	= 871,
    TRICORE_MSUBM_H_rrr1_LU	= 872,
    TRICORE_MSUBM_H_rrr1_UL	= 873,
    TRICORE_MSUBM_H_rrr1_UU	= 874,
    TRICORE_MSUBM_H_rrr1_v110	= 875,
    TRICORE_MSUBM_Q_rrr1_v110	= 876,
    TRICORE_MSUBM_U_rcrv110	= 877,
    TRICORE_MSUBM_U_rrr2v110	= 878,
    TRICORE_MSUBM_rcrv110	= 879,
    TRICORE_MSUBM_rrr2v110	= 880,
    TRICORE_MSUBRS_H_rrr1_LL	= 881,
    TRICORE_MSUBRS_H_rrr1_LU	= 882,
    TRICORE_MSUBRS_H_rrr1_UL	= 883,
    TRICORE_MSUBRS_H_rrr1_UL_2	= 884,
    TRICORE_MSUBRS_H_rrr1_UU	= 885,
    TRICORE_MSUBRS_H_rrr1_v110	= 886,
    TRICORE_MSUBRS_Q_rrr1_L_L	= 887,
    TRICORE_MSUBRS_Q_rrr1_U_U	= 888,
    TRICORE_MSUBRS_Q_rrr1_v110	= 889,
    TRICORE_MSUBR_H_rrr1_LL	= 890,
    TRICORE_MSUBR_H_rrr1_LU	= 891,
    TRICORE_MSUBR_H_rrr1_UL	= 892,
    TRICORE_MSUBR_H_rrr1_UL_2	= 893,
    TRICORE_MSUBR_H_rrr1_UU	= 894,
    TRICORE_MSUBR_H_rrr1_v110	= 895,
    TRICORE_MSUBR_Q_rrr1_L_L	= 896,
    TRICORE_MSUBR_Q_rrr1_U_U	= 897,
    TRICORE_MSUBR_Q_rrr1_v110	= 898,
    TRICORE_MSUBS_H_rrr1_LL	= 899,
    TRICORE_MSUBS_H_rrr1_LU	= 900,
    TRICORE_MSUBS_H_rrr1_UL	= 901,
    TRICORE_MSUBS_H_rrr1_UU	= 902,
    TRICORE_MSUBS_H_rrr1_v110	= 903,
    TRICORE_MSUBS_Q_rrr1	= 904,
    TRICORE_MSUBS_Q_rrr1_L	= 905,
    TRICORE_MSUBS_Q_rrr1_L_L	= 906,
    TRICORE_MSUBS_Q_rrr1_U	= 907,
    TRICORE_MSUBS_Q_rrr1_UU2_v110	= 908,
    TRICORE_MSUBS_Q_rrr1_U_U	= 909,
    TRICORE_MSUBS_Q_rrr1_e	= 910,
    TRICORE_MSUBS_Q_rrr1_e_L	= 911,
    TRICORE_MSUBS_Q_rrr1_e_L_L	= 912,
    TRICORE_MSUBS_Q_rrr1_e_U	= 913,
    TRICORE_MSUBS_Q_rrr1_e_U_U	= 914,
    TRICORE_MSUBS_U_rcr	= 915,
    TRICORE_MSUBS_U_rcr_e	= 916,
    TRICORE_MSUBS_U_rrr2	= 917,
    TRICORE_MSUBS_U_rrr2_e	= 918,
    TRICORE_MSUBS_rcr	= 919,
    TRICORE_MSUBS_rcr_e	= 920,
    TRICORE_MSUBS_rrr2	= 921,
    TRICORE_MSUBS_rrr2_e	= 922,
    TRICORE_MSUB_F_rrr	= 923,
    TRICORE_MSUB_H_rrr1_LL	= 924,
    TRICORE_MSUB_H_rrr1_LU	= 925,
    TRICORE_MSUB_H_rrr1_UL	= 926,
    TRICORE_MSUB_H_rrr1_UU	= 927,
    TRICORE_MSUB_H_rrr1_v110	= 928,
    TRICORE_MSUB_Q_rrr1	= 929,
    TRICORE_MSUB_Q_rrr1_L	= 930,
    TRICORE_MSUB_Q_rrr1_L_L	= 931,
    TRICORE_MSUB_Q_rrr1_U	= 932,
    TRICORE_MSUB_Q_rrr1_UU2_v110	= 933,
    TRICORE_MSUB_Q_rrr1_U_U	= 934,
    TRICORE_MSUB_Q_rrr1_e	= 935,
    TRICORE_MSUB_Q_rrr1_e_L	= 936,
    TRICORE_MSUB_Q_rrr1_e_L_L	= 937,
    TRICORE_MSUB_Q_rrr1_e_U	= 938,
    TRICORE_MSUB_Q_rrr1_e_U_U	= 939,
    TRICORE_MSUB_U_rcr	= 940,
    TRICORE_MSUB_U_rrr2	= 941,
    TRICORE_MSUB_rcr	= 942,
    TRICORE_MSUB_rcr_e	= 943,
    TRICORE_MSUB_rrr2	= 944,
    TRICORE_MSUB_rrr2_e	= 945,
    TRICORE_MTCR_rlc	= 946,
    TRICORE_MULMS_H_rr1_LL2e	= 947,
    TRICORE_MULMS_H_rr1_LU2e	= 948,
    TRICORE_MULMS_H_rr1_UL2e	= 949,
    TRICORE_MULMS_H_rr1_UU2e	= 950,
    TRICORE_MULM_H_rr1_LL2e	= 951,
    TRICORE_MULM_H_rr1_LU2e	= 952,
    TRICORE_MULM_H_rr1_UL2e	= 953,
    TRICORE_MULM_H_rr1_UU2e	= 954,
    TRICORE_MULM_U_rc	= 955,
    TRICORE_MULM_U_rr	= 956,
    TRICORE_MULM_rc	= 957,
    TRICORE_MULM_rr	= 958,
    TRICORE_MULR_H_rr1_LL2e	= 959,
    TRICORE_MULR_H_rr1_LU2e	= 960,
    TRICORE_MULR_H_rr1_UL2e	= 961,
    TRICORE_MULR_H_rr1_UU2e	= 962,
    TRICORE_MULR_H_rr_v110	= 963,
    TRICORE_MULR_Q_rr1_2LL	= 964,
    TRICORE_MULR_Q_rr1_2UU	= 965,
    TRICORE_MULR_Q_rr_v110	= 966,
    TRICORE_MULS_U_rc	= 967,
    TRICORE_MULS_U_rr2	= 968,
    TRICORE_MULS_U_rr_v110	= 969,
    TRICORE_MULS_rc	= 970,
    TRICORE_MULS_rr2	= 971,
    TRICORE_MULS_rr_v110	= 972,
    TRICORE_MUL_F_rrr	= 973,
    TRICORE_MUL_H_rr1_LL2e	= 974,
    TRICORE_MUL_H_rr1_LU2e	= 975,
    TRICORE_MUL_H_rr1_UL2e	= 976,
    TRICORE_MUL_H_rr1_UU2e	= 977,
    TRICORE_MUL_H_rr_v110	= 978,
    TRICORE_MUL_Q_rr1_2	= 979,
    TRICORE_MUL_Q_rr1_2LL	= 980,
    TRICORE_MUL_Q_rr1_2UU	= 981,
    TRICORE_MUL_Q_rr1_2_L	= 982,
    TRICORE_MUL_Q_rr1_2_Le	= 983,
    TRICORE_MUL_Q_rr1_2_U	= 984,
    TRICORE_MUL_Q_rr1_2_Ue	= 985,
    TRICORE_MUL_Q_rr1_2__e	= 986,
    TRICORE_MUL_Q_rr_v110	= 987,
    TRICORE_MUL_U_rc	= 988,
    TRICORE_MUL_U_rr2	= 989,
    TRICORE_MUL_rc	= 990,
    TRICORE_MUL_rc_e	= 991,
    TRICORE_MUL_rr2	= 992,
    TRICORE_MUL_rr2_e	= 993,
    TRICORE_MUL_rr_v110	= 994,
    TRICORE_MUL_srr	= 995,
    TRICORE_NAND_T	= 996,
    TRICORE_NAND_rc	= 997,
    TRICORE_NAND_rr	= 998,
    TRICORE_NEZ_A	= 999,
    TRICORE_NE_A	= 1000,
    TRICORE_NE_rc	= 1001,
    TRICORE_NE_rr	= 1002,
    TRICORE_NOP_sr	= 1003,
    TRICORE_NOP_sys	= 1004,
    TRICORE_NOR_T	= 1005,
    TRICORE_NOR_rc	= 1006,
    TRICORE_NOR_rr	= 1007,
    TRICORE_NOR_sr	= 1008,
    TRICORE_NOR_sr_v110	= 1009,
    TRICORE_NOT_sr_v162	= 1010,
    TRICORE_ORN_T	= 1011,
    TRICORE_ORN_rc	= 1012,
    TRICORE_ORN_rr	= 1013,
    TRICORE_OR_ANDN_T	= 1014,
    TRICORE_OR_AND_T	= 1015,
    TRICORE_OR_EQ_rc	= 1016,
    TRICORE_OR_EQ_rr	= 1017,
    TRICORE_OR_GE_U_rc	= 1018,
    TRICORE_OR_GE_U_rr	= 1019,
    TRICORE_OR_GE_rc	= 1020,
    TRICORE_OR_GE_rr	= 1021,
    TRICORE_OR_LT_U_rc	= 1022,
    TRICORE_OR_LT_U_rr	= 1023,
    TRICORE_OR_LT_rc	= 1024,
    TRICORE_OR_LT_rr	= 1025,
    TRICORE_OR_NE_rc	= 1026,
    TRICORE_OR_NE_rr	= 1027,
    TRICORE_OR_NOR_T	= 1028,
    TRICORE_OR_OR_T	= 1029,
    TRICORE_OR_T	= 1030,
    TRICORE_OR_rc	= 1031,
    TRICORE_OR_rr	= 1032,
    TRICORE_OR_sc	= 1033,
    TRICORE_OR_sc_v110	= 1034,
    TRICORE_OR_srr	= 1035,
    TRICORE_OR_srr_v110	= 1036,
    TRICORE_PACK_rrr	= 1037,
    TRICORE_PARITY_rr	= 1038,
    TRICORE_PARITY_rr_v110	= 1039,
    TRICORE_POPCNT_W_rr	= 1040,
    TRICORE_Q31TOF_rr	= 1041,
    TRICORE_QSEED_F_rr	= 1042,
    TRICORE_RESTORE_sys	= 1043,
    TRICORE_RET_sr	= 1044,
    TRICORE_RET_sys	= 1045,
    TRICORE_RET_sys_v110	= 1046,
    TRICORE_RFE_sr	= 1047,
    TRICORE_RFE_sys_sys	= 1048,
    TRICORE_RFE_sys_sys_v110	= 1049,
    TRICORE_RFM_sys	= 1050,
    TRICORE_RSLCX_sys	= 1051,
    TRICORE_RSTV_sys	= 1052,
    TRICORE_RSUBS_U_rc	= 1053,
    TRICORE_RSUBS_rc	= 1054,
    TRICORE_RSUB_rc	= 1055,
    TRICORE_RSUB_sr_sr	= 1056,
    TRICORE_RSUB_sr_sr_v110	= 1057,
    TRICORE_SAT_BU_rr	= 1058,
    TRICORE_SAT_BU_sr	= 1059,
    TRICORE_SAT_BU_sr_v110	= 1060,
    TRICORE_SAT_B_rr	= 1061,
    TRICORE_SAT_B_sr	= 1062,
    TRICORE_SAT_B_sr_v110	= 1063,
    TRICORE_SAT_HU_rr	= 1064,
    TRICORE_SAT_HU_sr	= 1065,
    TRICORE_SAT_HU_sr_v110	= 1066,
    TRICORE_SAT_H_rr	= 1067,
    TRICORE_SAT_H_sr	= 1068,
    TRICORE_SAT_H_sr_v110	= 1069,
    TRICORE_SELN_A_rcr_v110	= 1070,
    TRICORE_SELN_A_rrr_v110	= 1071,
    TRICORE_SELN_rcr	= 1072,
    TRICORE_SELN_rrr	= 1073,
    TRICORE_SEL_A_rcr_v110	= 1074,
    TRICORE_SEL_A_rrr_v110	= 1075,
    TRICORE_SEL_rcr	= 1076,
    TRICORE_SEL_rrr	= 1077,
    TRICORE_SHAS_rc	= 1078,
    TRICORE_SHAS_rr	= 1079,
    TRICORE_SHA_B_rc	= 1080,
    TRICORE_SHA_B_rr	= 1081,
    TRICORE_SHA_H_rc	= 1082,
    TRICORE_SHA_H_rr	= 1083,
    TRICORE_SHA_rc	= 1084,
    TRICORE_SHA_rr	= 1085,
    TRICORE_SHA_src	= 1086,
    TRICORE_SHA_src_v110	= 1087,
    TRICORE_SHUFFLE_rc	= 1088,
    TRICORE_SH_ANDN_T	= 1089,
    TRICORE_SH_AND_T	= 1090,
    TRICORE_SH_B_rc	= 1091,
    TRICORE_SH_B_rr	= 1092,
    TRICORE_SH_EQ_rc	= 1093,
    TRICORE_SH_EQ_rr	= 1094,
    TRICORE_SH_GE_U_rc	= 1095,
    TRICORE_SH_GE_U_rr	= 1096,
    TRICORE_SH_GE_rc	= 1097,
    TRICORE_SH_GE_rr	= 1098,
    TRICORE_SH_H_rc	= 1099,
    TRICORE_SH_H_rr	= 1100,
    TRICORE_SH_LT_U_rc	= 1101,
    TRICORE_SH_LT_U_rr	= 1102,
    TRICORE_SH_LT_rc	= 1103,
    TRICORE_SH_LT_rr	= 1104,
    TRICORE_SH_NAND_T	= 1105,
    TRICORE_SH_NE_rc	= 1106,
    TRICORE_SH_NE_rr	= 1107,
    TRICORE_SH_NOR_T	= 1108,
    TRICORE_SH_ORN_T	= 1109,
    TRICORE_SH_OR_T	= 1110,
    TRICORE_SH_XNOR_T	= 1111,
    TRICORE_SH_XOR_T	= 1112,
    TRICORE_SH_rc	= 1113,
    TRICORE_SH_rr	= 1114,
    TRICORE_SH_src	= 1115,
    TRICORE_SH_src_v110	= 1116,
    TRICORE_STLCX_abs	= 1117,
    TRICORE_STLCX_bo_bso	= 1118,
    TRICORE_STUCX_abs	= 1119,
    TRICORE_STUCX_bo_bso	= 1120,
    TRICORE_ST_A_abs	= 1121,
    TRICORE_ST_A_bo_bso	= 1122,
    TRICORE_ST_A_bo_c	= 1123,
    TRICORE_ST_A_bo_pos	= 1124,
    TRICORE_ST_A_bo_pre	= 1125,
    TRICORE_ST_A_bo_r	= 1126,
    TRICORE_ST_A_bol	= 1127,
    TRICORE_ST_A_sc	= 1128,
    TRICORE_ST_A_sro	= 1129,
    TRICORE_ST_A_sro_v110	= 1130,
    TRICORE_ST_A_ssr	= 1131,
    TRICORE_ST_A_ssr_pos	= 1132,
    TRICORE_ST_A_ssr_pos_v110	= 1133,
    TRICORE_ST_A_ssr_v110	= 1134,
    TRICORE_ST_A_ssro	= 1135,
    TRICORE_ST_A_ssro_v110	= 1136,
    TRICORE_ST_B_abs	= 1137,
    TRICORE_ST_B_bo_bso	= 1138,
    TRICORE_ST_B_bo_c	= 1139,
    TRICORE_ST_B_bo_pos	= 1140,
    TRICORE_ST_B_bo_pre	= 1141,
    TRICORE_ST_B_bo_r	= 1142,
    TRICORE_ST_B_bol	= 1143,
    TRICORE_ST_B_sro	= 1144,
    TRICORE_ST_B_sro_v110	= 1145,
    TRICORE_ST_B_ssr	= 1146,
    TRICORE_ST_B_ssr_pos	= 1147,
    TRICORE_ST_B_ssr_pos_v110	= 1148,
    TRICORE_ST_B_ssr_v110	= 1149,
    TRICORE_ST_B_ssro	= 1150,
    TRICORE_ST_B_ssro_v110	= 1151,
    TRICORE_ST_DA_abs	= 1152,
    TRICORE_ST_DA_bo_bso	= 1153,
    TRICORE_ST_DA_bo_c	= 1154,
    TRICORE_ST_DA_bo_pos	= 1155,
    TRICORE_ST_DA_bo_pre	= 1156,
    TRICORE_ST_DA_bo_r	= 1157,
    TRICORE_ST_D_abs	= 1158,
    TRICORE_ST_D_bo_bso	= 1159,
    TRICORE_ST_D_bo_c	= 1160,
    TRICORE_ST_D_bo_pos	= 1161,
    TRICORE_ST_D_bo_pre	= 1162,
    TRICORE_ST_D_bo_r	= 1163,
    TRICORE_ST_H_abs	= 1164,
    TRICORE_ST_H_bo_bso	= 1165,
    TRICORE_ST_H_bo_c	= 1166,
    TRICORE_ST_H_bo_pos	= 1167,
    TRICORE_ST_H_bo_pre	= 1168,
    TRICORE_ST_H_bo_r	= 1169,
    TRICORE_ST_H_bol	= 1170,
    TRICORE_ST_H_sro	= 1171,
    TRICORE_ST_H_sro_v110	= 1172,
    TRICORE_ST_H_ssr	= 1173,
    TRICORE_ST_H_ssr_pos	= 1174,
    TRICORE_ST_H_ssr_pos_v110	= 1175,
    TRICORE_ST_H_ssr_v110	= 1176,
    TRICORE_ST_H_ssro	= 1177,
    TRICORE_ST_H_ssro_v110	= 1178,
    TRICORE_ST_Q_abs	= 1179,
    TRICORE_ST_Q_bo_bso	= 1180,
    TRICORE_ST_Q_bo_c	= 1181,
    TRICORE_ST_Q_bo_pos	= 1182,
    TRICORE_ST_Q_bo_pre	= 1183,
    TRICORE_ST_Q_bo_r	= 1184,
    TRICORE_ST_T	= 1185,
    TRICORE_ST_W_abs	= 1186,
    TRICORE_ST_W_bo_bso	= 1187,
    TRICORE_ST_W_bo_c	= 1188,
    TRICORE_ST_W_bo_pos	= 1189,
    TRICORE_ST_W_bo_pre	= 1190,
    TRICORE_ST_W_bo_r	= 1191,
    TRICORE_ST_W_bol	= 1192,
    TRICORE_ST_W_sc	= 1193,
    TRICORE_ST_W_sro	= 1194,
    TRICORE_ST_W_sro_v110	= 1195,
    TRICORE_ST_W_ssr	= 1196,
    TRICORE_ST_W_ssr_pos	= 1197,
    TRICORE_ST_W_ssr_pos_v110	= 1198,
    TRICORE_ST_W_ssr_v110	= 1199,
    TRICORE_ST_W_ssro	= 1200,
    TRICORE_ST_W_ssro_v110	= 1201,
    TRICORE_SUBC_rr	= 1202,
    TRICORE_SUBSC_A_rr	= 1203,
    TRICORE_SUBS_BU_rr	= 1204,
    TRICORE_SUBS_B_rr	= 1205,
    TRICORE_SUBS_HU_rr	= 1206,
    TRICORE_SUBS_H_rr	= 1207,
    TRICORE_SUBS_U_rr	= 1208,
    TRICORE_SUBS_rr	= 1209,
    TRICORE_SUBS_srr	= 1210,
    TRICORE_SUBX_rr	= 1211,
    TRICORE_SUB_A_rr	= 1212,
    TRICORE_SUB_A_sc	= 1213,
    TRICORE_SUB_A_sc_v110	= 1214,
    TRICORE_SUB_B_rr	= 1215,
    TRICORE_SUB_F_rrr	= 1216,
    TRICORE_SUB_H_rr	= 1217,
    TRICORE_SUB_rr	= 1218,
    TRICORE_SUB_srr	= 1219,
    TRICORE_SUB_srr_15a	= 1220,
    TRICORE_SUB_srr_a15	= 1221,
    TRICORE_SVLCX_sys	= 1222,
    TRICORE_SWAPMSK_W_bo_bso	= 1223,
    TRICORE_SWAPMSK_W_bo_c	= 1224,
    TRICORE_SWAPMSK_W_bo_i	= 1225,
    TRICORE_SWAPMSK_W_bo_pos	= 1226,
    TRICORE_SWAPMSK_W_bo_pre	= 1227,
    TRICORE_SWAPMSK_W_bo_r	= 1228,
    TRICORE_SWAP_A_abs	= 1229,
    TRICORE_SWAP_A_bo_bso	= 1230,
    TRICORE_SWAP_A_bo_c	= 1231,
    TRICORE_SWAP_A_bo_pos	= 1232,
    TRICORE_SWAP_A_bo_pre	= 1233,
    TRICORE_SWAP_A_bo_r	= 1234,
    TRICORE_SWAP_W_abs	= 1235,
    TRICORE_SWAP_W_bo_bso	= 1236,
    TRICORE_SWAP_W_bo_c	= 1237,
    TRICORE_SWAP_W_bo_i	= 1238,
    TRICORE_SWAP_W_bo_pos	= 1239,
    TRICORE_SWAP_W_bo_pre	= 1240,
    TRICORE_SWAP_W_bo_r	= 1241,
    TRICORE_SYSCALL_rc	= 1242,
    TRICORE_TLBDEMAP_rr	= 1243,
    TRICORE_TLBFLUSH_A_rr	= 1244,
    TRICORE_TLBFLUSH_B_rr	= 1245,
    TRICORE_TLBMAP_rr	= 1246,
    TRICORE_TLBPROBE_A_rr	= 1247,
    TRICORE_TLBPROBE_I_rr	= 1248,
    TRICORE_TRAPSV_sys	= 1249,
    TRICORE_TRAPV_sys	= 1250,
    TRICORE_UNPACK_rr_rr	= 1251,
    TRICORE_UNPACK_rr_rr_v110	= 1252,
    TRICORE_UPDFL_rr	= 1253,
    TRICORE_UTOF_rr	= 1254,
    TRICORE_WAIT_sys	= 1255,
    TRICORE_XNOR_T	= 1256,
    TRICORE_XNOR_rc	= 1257,
    TRICORE_XNOR_rr	= 1258,
    TRICORE_XOR_EQ_rc	= 1259,
    TRICORE_XOR_EQ_rr	= 1260,
    TRICORE_XOR_GE_U_rc	= 1261,
    TRICORE_XOR_GE_U_rr	= 1262,
    TRICORE_XOR_GE_rc	= 1263,
    TRICORE_XOR_GE_rr	= 1264,
    TRICORE_XOR_LT_U_rc	= 1265,
    TRICORE_XOR_LT_U_rr	= 1266,
    TRICORE_XOR_LT_rc	= 1267,
    TRICORE_XOR_LT_rr	= 1268,
    TRICORE_XOR_NE_rc	= 1269,
    TRICORE_XOR_NE_rr	= 1270,
    TRICORE_XOR_T	= 1271,
    TRICORE_XOR_rc	= 1272,
    TRICORE_XOR_rr	= 1273,
    TRICORE_XOR_srr	= 1274,
    INSTRUCTION_LIST_END = 1275
  };

#endif // GET_INSTRINFO_ENUM

#ifdef GET_INSTRINFO_MC_DESC
#undef GET_INSTRINFO_MC_DESC


static const MCOperandInfo OperandInfo2[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo3[] = { { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo4[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo5[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, CONSTRAINT_MCOI_TIED_TO(0) }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo6[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo7[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo8[] = { { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo9[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, CONSTRAINT_MCOI_TIED_TO(0) }, };
static const MCOperandInfo OperandInfo10[] = { { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo11[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo12[] = { { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo13[] = { { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo14[] = { { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo15[] = { { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo16[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo17[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_IMM_0, 0 }, };
static const MCOperandInfo OperandInfo18[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, };
static const MCOperandInfo OperandInfo19[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, };
static const MCOperandInfo OperandInfo20[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, };
static const MCOperandInfo OperandInfo21[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo22[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_IMM_0, 0 }, };
static const MCOperandInfo OperandInfo23[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, };
static const MCOperandInfo OperandInfo24[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_IMM_0, 0 }, };
static const MCOperandInfo OperandInfo25[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, };
static const MCOperandInfo OperandInfo26[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo27[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_2, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo28[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_2, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo29[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_2, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, };
static const MCOperandInfo OperandInfo30[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, };
static const MCOperandInfo OperandInfo31[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, };
static const MCOperandInfo OperandInfo32[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo33[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, };
static const MCOperandInfo OperandInfo34[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, };
static const MCOperandInfo OperandInfo35[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, };
static const MCOperandInfo OperandInfo36[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, };
static const MCOperandInfo OperandInfo37[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_IMM_0, 0 }, };
static const MCOperandInfo OperandInfo38[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, };
static const MCOperandInfo OperandInfo39[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_2, 0 }, };
static const MCOperandInfo OperandInfo40[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_2, 0 }, };
static const MCOperandInfo OperandInfo41[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo42[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, };
static const MCOperandInfo OperandInfo43[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_2, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_IMM_0, 0 }, };
static const MCOperandInfo OperandInfo44[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, };
static const MCOperandInfo OperandInfo45[] = { { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo46[] = { { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo47[] = { { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo48[] = { { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo49[] = { { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo50[] = { { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo51[] = { { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo52[] = { { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo53[] = { { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo54[] = { { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo55[] = { { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo56[] = { { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo57[] = { { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo58[] = { { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo59[] = { { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo60[] = { { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo61[] = { { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo62[] = { { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo63[] = { { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo64[] = { { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo65[] = { { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo66[] = { { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo67[] = { { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo68[] = { { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo69[] = { { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo70[] = { { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo71[] = { { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo72[] = { { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo73[] = { { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo74[] = { { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo75[] = { { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo76[] = { { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo77[] = { { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo78[] = { { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo79[] = { { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo80[] = { { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo81[] = { { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo82[] = { { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo83[] = { { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo84[] = { { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo85[] = { { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo86[] = { { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo87[] = { { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo88[] = { { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo89[] = { { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo90[] = { { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo91[] = { { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo92[] = { { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo93[] = { { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo94[] = { { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo95[] = { { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo96[] = { { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo97[] = { { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo98[] = { { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo99[] = { { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo100[] = { { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo101[] = { { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo102[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo103[] = { { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo104[] = { { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo105[] = { { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RARegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo106[] = { { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo107[] = { { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RDRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo108[] = { { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo109[] = { { TriCore_RPRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo110[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo111[] = { { TriCore_RERegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };

static const MCInstrDesc TriCoreInsts[] = {
  { 1, OperandInfo2 },  // Inst #0 = PHI
  { 0, 0 },  // Inst #1 = INLINEASM
  { 0, 0 },  // Inst #2 = INLINEASM_BR
  { 1, OperandInfo3 },  // Inst #3 = CFI_INSTRUCTION
  { 1, OperandInfo3 },  // Inst #4 = EH_LABEL
  { 1, OperandInfo3 },  // Inst #5 = GC_LABEL
  { 1, OperandInfo3 },  // Inst #6 = ANNOTATION_LABEL
  { 0, 0 },  // Inst #7 = KILL
  { 3, OperandInfo4 },  // Inst #8 = EXTRACT_SUBREG
  { 4, OperandInfo5 },  // Inst #9 = INSERT_SUBREG
  { 1, OperandInfo2 },  // Inst #10 = IMPLICIT_DEF
  { 4, OperandInfo6 },  // Inst #11 = SUBREG_TO_REG
  { 3, OperandInfo4 },  // Inst #12 = COPY_TO_REGCLASS
  { 0, 0 },  // Inst #13 = DBG_VALUE
  { 0, 0 },  // Inst #14 = DBG_VALUE_LIST
  { 0, 0 },  // Inst #15 = DBG_INSTR_REF
  { 0, 0 },  // Inst #16 = DBG_PHI
  { 1, OperandInfo2 },  // Inst #17 = DBG_LABEL
  { 2, OperandInfo7 },  // Inst #18 = REG_SEQUENCE
  { 2, OperandInfo7 },  // Inst #19 = COPY
  { 0, 0 },  // Inst #20 = BUNDLE
  { 1, OperandInfo3 },  // Inst #21 = LIFETIME_START
  { 1, OperandInfo3 },  // Inst #22 = LIFETIME_END
  { 4, OperandInfo8 },  // Inst #23 = PSEUDO_PROBE
  { 2, OperandInfo9 },  // Inst #24 = ARITH_FENCE
  { 2, OperandInfo10 },  // Inst #25 = STACKMAP
  { 0, 0 },  // Inst #26 = FENTRY_CALL
  { 6, OperandInfo11 },  // Inst #27 = PATCHPOINT
  { 1, OperandInfo12 },  // Inst #28 = LOAD_STACK_GUARD
  { 1, OperandInfo3 },  // Inst #29 = PREALLOCATED_SETUP
  { 3, OperandInfo13 },  // Inst #30 = PREALLOCATED_ARG
  { 0, 0 },  // Inst #31 = STATEPOINT
  { 2, OperandInfo14 },  // Inst #32 = LOCAL_ESCAPE
  { 1, OperandInfo2 },  // Inst #33 = FAULTING_OP
  { 0, 0 },  // Inst #34 = PATCHABLE_OP
  { 0, 0 },  // Inst #35 = PATCHABLE_FUNCTION_ENTER
  { 0, 0 },  // Inst #36 = PATCHABLE_RET
  { 0, 0 },  // Inst #37 = PATCHABLE_FUNCTION_EXIT
  { 0, 0 },  // Inst #38 = PATCHABLE_TAIL_CALL
  { 2, OperandInfo15 },  // Inst #39 = PATCHABLE_EVENT_CALL
  { 3, OperandInfo16 },  // Inst #40 = PATCHABLE_TYPED_EVENT_CALL
  { 0, 0 },  // Inst #41 = ICALL_BRANCH_FUNNEL
  { 0, 0 },  // Inst #42 = MEMBARRIER
  { 3, OperandInfo17 },  // Inst #43 = G_ASSERT_SEXT
  { 3, OperandInfo17 },  // Inst #44 = G_ASSERT_ZEXT
  { 3, OperandInfo17 },  // Inst #45 = G_ASSERT_ALIGN
  { 3, OperandInfo18 },  // Inst #46 = G_ADD
  { 3, OperandInfo18 },  // Inst #47 = G_SUB
  { 3, OperandInfo18 },  // Inst #48 = G_MUL
  { 3, OperandInfo18 },  // Inst #49 = G_SDIV
  { 3, OperandInfo18 },  // Inst #50 = G_UDIV
  { 3, OperandInfo18 },  // Inst #51 = G_SREM
  { 3, OperandInfo18 },  // Inst #52 = G_UREM
  { 4, OperandInfo19 },  // Inst #53 = G_SDIVREM
  { 4, OperandInfo19 },  // Inst #54 = G_UDIVREM
  { 3, OperandInfo18 },  // Inst #55 = G_AND
  { 3, OperandInfo18 },  // Inst #56 = G_OR
  { 3, OperandInfo18 },  // Inst #57 = G_XOR
  { 1, OperandInfo20 },  // Inst #58 = G_IMPLICIT_DEF
  { 1, OperandInfo20 },  // Inst #59 = G_PHI
  { 2, OperandInfo21 },  // Inst #60 = G_FRAME_INDEX
  { 2, OperandInfo21 },  // Inst #61 = G_GLOBAL_VALUE
  { 3, OperandInfo22 },  // Inst #62 = G_EXTRACT
  { 2, OperandInfo23 },  // Inst #63 = G_UNMERGE_VALUES
  { 4, OperandInfo24 },  // Inst #64 = G_INSERT
  { 2, OperandInfo23 },  // Inst #65 = G_MERGE_VALUES
  { 2, OperandInfo23 },  // Inst #66 = G_BUILD_VECTOR
  { 2, OperandInfo23 },  // Inst #67 = G_BUILD_VECTOR_TRUNC
  { 2, OperandInfo23 },  // Inst #68 = G_CONCAT_VECTORS
  { 2, OperandInfo23 },  // Inst #69 = G_PTRTOINT
  { 2, OperandInfo23 },  // Inst #70 = G_INTTOPTR
  { 2, OperandInfo23 },  // Inst #71 = G_BITCAST
  { 2, OperandInfo25 },  // Inst #72 = G_FREEZE
  { 3, OperandInfo26 },  // Inst #73 = G_INTRINSIC_FPTRUNC_ROUND
  { 2, OperandInfo25 },  // Inst #74 = G_INTRINSIC_TRUNC
  { 2, OperandInfo25 },  // Inst #75 = G_INTRINSIC_ROUND
  { 2, OperandInfo23 },  // Inst #76 = G_INTRINSIC_LRINT
  { 2, OperandInfo25 },  // Inst #77 = G_INTRINSIC_ROUNDEVEN
  { 1, OperandInfo20 },  // Inst #78 = G_READCYCLECOUNTER
  { 2, OperandInfo23 },  // Inst #79 = G_LOAD
  { 2, OperandInfo23 },  // Inst #80 = G_SEXTLOAD
  { 2, OperandInfo23 },  // Inst #81 = G_ZEXTLOAD
  { 5, OperandInfo27 },  // Inst #82 = G_INDEXED_LOAD
  { 5, OperandInfo27 },  // Inst #83 = G_INDEXED_SEXTLOAD
  { 5, OperandInfo27 },  // Inst #84 = G_INDEXED_ZEXTLOAD
  { 2, OperandInfo23 },  // Inst #85 = G_STORE
  { 5, OperandInfo28 },  // Inst #86 = G_INDEXED_STORE
  { 5, OperandInfo29 },  // Inst #87 = G_ATOMIC_CMPXCHG_WITH_SUCCESS
  { 4, OperandInfo30 },  // Inst #88 = G_ATOMIC_CMPXCHG
  { 3, OperandInfo31 },  // Inst #89 = G_ATOMICRMW_XCHG
  { 3, OperandInfo31 },  // Inst #90 = G_ATOMICRMW_ADD
  { 3, OperandInfo31 },  // Inst #91 = G_ATOMICRMW_SUB
  { 3, OperandInfo31 },  // Inst #92 = G_ATOMICRMW_AND
  { 3, OperandInfo31 },  // Inst #93 = G_ATOMICRMW_NAND
  { 3, OperandInfo31 },  // Inst #94 = G_ATOMICRMW_OR
  { 3, OperandInfo31 },  // Inst #95 = G_ATOMICRMW_XOR
  { 3, OperandInfo31 },  // Inst #96 = G_ATOMICRMW_MAX
  { 3, OperandInfo31 },  // Inst #97 = G_ATOMICRMW_MIN
  { 3, OperandInfo31 },  // Inst #98 = G_ATOMICRMW_UMAX
  { 3, OperandInfo31 },  // Inst #99 = G_ATOMICRMW_UMIN
  { 3, OperandInfo31 },  // Inst #100 = G_ATOMICRMW_FADD
  { 3, OperandInfo31 },  // Inst #101 = G_ATOMICRMW_FSUB
  { 3, OperandInfo31 },  // Inst #102 = G_ATOMICRMW_FMAX
  { 3, OperandInfo31 },  // Inst #103 = G_ATOMICRMW_FMIN
  { 3, OperandInfo31 },  // Inst #104 = G_ATOMICRMW_UINC_WRAP
  { 3, OperandInfo31 },  // Inst #105 = G_ATOMICRMW_UDEC_WRAP
  { 2, OperandInfo10 },  // Inst #106 = G_FENCE
  { 2, OperandInfo21 },  // Inst #107 = G_BRCOND
  { 1, OperandInfo20 },  // Inst #108 = G_BRINDIRECT
  { 0, 0 },  // Inst #109 = G_INVOKE_REGION_START
  { 1, OperandInfo2 },  // Inst #110 = G_INTRINSIC
  { 1, OperandInfo2 },  // Inst #111 = G_INTRINSIC_W_SIDE_EFFECTS
  { 2, OperandInfo23 },  // Inst #112 = G_ANYEXT
  { 2, OperandInfo23 },  // Inst #113 = G_TRUNC
  { 2, OperandInfo21 },  // Inst #114 = G_CONSTANT
  { 2, OperandInfo21 },  // Inst #115 = G_FCONSTANT
  { 1, OperandInfo20 },  // Inst #116 = G_VASTART
  { 3, OperandInfo32 },  // Inst #117 = G_VAARG
  { 2, OperandInfo23 },  // Inst #118 = G_SEXT
  { 3, OperandInfo17 },  // Inst #119 = G_SEXT_INREG
  { 2, OperandInfo23 },  // Inst #120 = G_ZEXT
  { 3, OperandInfo33 },  // Inst #121 = G_SHL
  { 3, OperandInfo33 },  // Inst #122 = G_LSHR
  { 3, OperandInfo33 },  // Inst #123 = G_ASHR
  { 4, OperandInfo34 },  // Inst #124 = G_FSHL
  { 4, OperandInfo34 },  // Inst #125 = G_FSHR
  { 3, OperandInfo33 },  // Inst #126 = G_ROTR
  { 3, OperandInfo33 },  // Inst #127 = G_ROTL
  { 4, OperandInfo35 },  // Inst #128 = G_ICMP
  { 4, OperandInfo35 },  // Inst #129 = G_FCMP
  { 4, OperandInfo30 },  // Inst #130 = G_SELECT
  { 4, OperandInfo30 },  // Inst #131 = G_UADDO
  { 5, OperandInfo36 },  // Inst #132 = G_UADDE
  { 4, OperandInfo30 },  // Inst #133 = G_USUBO
  { 5, OperandInfo36 },  // Inst #134 = G_USUBE
  { 4, OperandInfo30 },  // Inst #135 = G_SADDO
  { 5, OperandInfo36 },  // Inst #136 = G_SADDE
  { 4, OperandInfo30 },  // Inst #137 = G_SSUBO
  { 5, OperandInfo36 },  // Inst #138 = G_SSUBE
  { 4, OperandInfo30 },  // Inst #139 = G_UMULO
  { 4, OperandInfo30 },  // Inst #140 = G_SMULO
  { 3, OperandInfo18 },  // Inst #141 = G_UMULH
  { 3, OperandInfo18 },  // Inst #142 = G_SMULH
  { 3, OperandInfo18 },  // Inst #143 = G_UADDSAT
  { 3, OperandInfo18 },  // Inst #144 = G_SADDSAT
  { 3, OperandInfo18 },  // Inst #145 = G_USUBSAT
  { 3, OperandInfo18 },  // Inst #146 = G_SSUBSAT
  { 3, OperandInfo33 },  // Inst #147 = G_USHLSAT
  { 3, OperandInfo33 },  // Inst #148 = G_SSHLSAT
  { 4, OperandInfo37 },  // Inst #149 = G_SMULFIX
  { 4, OperandInfo37 },  // Inst #150 = G_UMULFIX
  { 4, OperandInfo37 },  // Inst #151 = G_SMULFIXSAT
  { 4, OperandInfo37 },  // Inst #152 = G_UMULFIXSAT
  { 4, OperandInfo37 },  // Inst #153 = G_SDIVFIX
  { 4, OperandInfo37 },  // Inst #154 = G_UDIVFIX
  { 4, OperandInfo37 },  // Inst #155 = G_SDIVFIXSAT
  { 4, OperandInfo37 },  // Inst #156 = G_UDIVFIXSAT
  { 3, OperandInfo18 },  // Inst #157 = G_FADD
  { 3, OperandInfo18 },  // Inst #158 = G_FSUB
  { 3, OperandInfo18 },  // Inst #159 = G_FMUL
  { 4, OperandInfo19 },  // Inst #160 = G_FMA
  { 4, OperandInfo19 },  // Inst #161 = G_FMAD
  { 3, OperandInfo18 },  // Inst #162 = G_FDIV
  { 3, OperandInfo18 },  // Inst #163 = G_FREM
  { 3, OperandInfo18 },  // Inst #164 = G_FPOW
  { 3, OperandInfo33 },  // Inst #165 = G_FPOWI
  { 2, OperandInfo25 },  // Inst #166 = G_FEXP
  { 2, OperandInfo25 },  // Inst #167 = G_FEXP2
  { 2, OperandInfo25 },  // Inst #168 = G_FLOG
  { 2, OperandInfo25 },  // Inst #169 = G_FLOG2
  { 2, OperandInfo25 },  // Inst #170 = G_FLOG10
  { 2, OperandInfo25 },  // Inst #171 = G_FNEG
  { 2, OperandInfo23 },  // Inst #172 = G_FPEXT
  { 2, OperandInfo23 },  // Inst #173 = G_FPTRUNC
  { 2, OperandInfo23 },  // Inst #174 = G_FPTOSI
  { 2, OperandInfo23 },  // Inst #175 = G_FPTOUI
  { 2, OperandInfo23 },  // Inst #176 = G_SITOFP
  { 2, OperandInfo23 },  // Inst #177 = G_UITOFP
  { 2, OperandInfo25 },  // Inst #178 = G_FABS
  { 3, OperandInfo33 },  // Inst #179 = G_FCOPYSIGN
  { 3, OperandInfo32 },  // Inst #180 = G_IS_FPCLASS
  { 2, OperandInfo25 },  // Inst #181 = G_FCANONICALIZE
  { 3, OperandInfo18 },  // Inst #182 = G_FMINNUM
  { 3, OperandInfo18 },  // Inst #183 = G_FMAXNUM
  { 3, OperandInfo18 },  // Inst #184 = G_FMINNUM_IEEE
  { 3, OperandInfo18 },  // Inst #185 = G_FMAXNUM_IEEE
  { 3, OperandInfo18 },  // Inst #186 = G_FMINIMUM
  { 3, OperandInfo18 },  // Inst #187 = G_FMAXIMUM
  { 3, OperandInfo33 },  // Inst #188 = G_PTR_ADD
  { 3, OperandInfo33 },  // Inst #189 = G_PTRMASK
  { 3, OperandInfo18 },  // Inst #190 = G_SMIN
  { 3, OperandInfo18 },  // Inst #191 = G_SMAX
  { 3, OperandInfo18 },  // Inst #192 = G_UMIN
  { 3, OperandInfo18 },  // Inst #193 = G_UMAX
  { 2, OperandInfo25 },  // Inst #194 = G_ABS
  { 2, OperandInfo23 },  // Inst #195 = G_LROUND
  { 2, OperandInfo23 },  // Inst #196 = G_LLROUND
  { 1, OperandInfo2 },  // Inst #197 = G_BR
  { 3, OperandInfo38 },  // Inst #198 = G_BRJT
  { 4, OperandInfo39 },  // Inst #199 = G_INSERT_VECTOR_ELT
  { 3, OperandInfo40 },  // Inst #200 = G_EXTRACT_VECTOR_ELT
  { 4, OperandInfo41 },  // Inst #201 = G_SHUFFLE_VECTOR
  { 2, OperandInfo23 },  // Inst #202 = G_CTTZ
  { 2, OperandInfo23 },  // Inst #203 = G_CTTZ_ZERO_UNDEF
  { 2, OperandInfo23 },  // Inst #204 = G_CTLZ
  { 2, OperandInfo23 },  // Inst #205 = G_CTLZ_ZERO_UNDEF
  { 2, OperandInfo23 },  // Inst #206 = G_CTPOP
  { 2, OperandInfo25 },  // Inst #207 = G_BSWAP
  { 2, OperandInfo25 },  // Inst #208 = G_BITREVERSE
  { 2, OperandInfo25 },  // Inst #209 = G_FCEIL
  { 2, OperandInfo25 },  // Inst #210 = G_FCOS
  { 2, OperandInfo25 },  // Inst #211 = G_FSIN
  { 2, OperandInfo25 },  // Inst #212 = G_FSQRT
  { 2, OperandInfo25 },  // Inst #213 = G_FFLOOR
  { 2, OperandInfo25 },  // Inst #214 = G_FRINT
  { 2, OperandInfo25 },  // Inst #215 = G_FNEARBYINT
  { 2, OperandInfo23 },  // Inst #216 = G_ADDRSPACE_CAST
  { 2, OperandInfo21 },  // Inst #217 = G_BLOCK_ADDR
  { 2, OperandInfo21 },  // Inst #218 = G_JUMP_TABLE
  { 3, OperandInfo26 },  // Inst #219 = G_DYN_STACKALLOC
  { 3, OperandInfo18 },  // Inst #220 = G_STRICT_FADD
  { 3, OperandInfo18 },  // Inst #221 = G_STRICT_FSUB
  { 3, OperandInfo18 },  // Inst #222 = G_STRICT_FMUL
  { 3, OperandInfo18 },  // Inst #223 = G_STRICT_FDIV
  { 3, OperandInfo18 },  // Inst #224 = G_STRICT_FREM
  { 4, OperandInfo19 },  // Inst #225 = G_STRICT_FMA
  { 2, OperandInfo25 },  // Inst #226 = G_STRICT_FSQRT
  { 2, OperandInfo21 },  // Inst #227 = G_READ_REGISTER
  { 2, OperandInfo42 },  // Inst #228 = G_WRITE_REGISTER
  { 4, OperandInfo43 },  // Inst #229 = G_MEMCPY
  { 3, OperandInfo40 },  // Inst #230 = G_MEMCPY_INLINE
  { 4, OperandInfo43 },  // Inst #231 = G_MEMMOVE
  { 4, OperandInfo43 },  // Inst #232 = G_MEMSET
  { 3, OperandInfo22 },  // Inst #233 = G_BZERO
  { 3, OperandInfo40 },  // Inst #234 = G_VECREDUCE_SEQ_FADD
  { 3, OperandInfo40 },  // Inst #235 = G_VECREDUCE_SEQ_FMUL
  { 2, OperandInfo23 },  // Inst #236 = G_VECREDUCE_FADD
  { 2, OperandInfo23 },  // Inst #237 = G_VECREDUCE_FMUL
  { 2, OperandInfo23 },  // Inst #238 = G_VECREDUCE_FMAX
  { 2, OperandInfo23 },  // Inst #239 = G_VECREDUCE_FMIN
  { 2, OperandInfo23 },  // Inst #240 = G_VECREDUCE_ADD
  { 2, OperandInfo23 },  // Inst #241 = G_VECREDUCE_MUL
  { 2, OperandInfo23 },  // Inst #242 = G_VECREDUCE_AND
  { 2, OperandInfo23 },  // Inst #243 = G_VECREDUCE_OR
  { 2, OperandInfo23 },  // Inst #244 = G_VECREDUCE_XOR
  { 2, OperandInfo23 },  // Inst #245 = G_VECREDUCE_SMAX
  { 2, OperandInfo23 },  // Inst #246 = G_VECREDUCE_SMIN
  { 2, OperandInfo23 },  // Inst #247 = G_VECREDUCE_UMAX
  { 2, OperandInfo23 },  // Inst #248 = G_VECREDUCE_UMIN
  { 4, OperandInfo44 },  // Inst #249 = G_SBFX
  { 4, OperandInfo44 },  // Inst #250 = G_UBFX
  { 3, OperandInfo45 },  // Inst #251 = ABSDIFS_B_rr_v110
  { 3, OperandInfo45 },  // Inst #252 = ABSDIFS_H_rr
  { 3, OperandInfo45 },  // Inst #253 = ABSDIFS_rc
  { 3, OperandInfo45 },  // Inst #254 = ABSDIFS_rr
  { 3, OperandInfo45 },  // Inst #255 = ABSDIF_B_rr
  { 3, OperandInfo45 },  // Inst #256 = ABSDIF_H_rr
  { 3, OperandInfo46 },  // Inst #257 = ABSDIF_rc
  { 3, OperandInfo45 },  // Inst #258 = ABSDIF_rr
  { 3, OperandInfo45 },  // Inst #259 = ABSS_B_rr_v110
  { 3, OperandInfo45 },  // Inst #260 = ABSS_H_rr
  { 3, OperandInfo45 },  // Inst #261 = ABSS_rr
  { 2, OperandInfo47 },  // Inst #262 = ABS_B_rr
  { 2, OperandInfo47 },  // Inst #263 = ABS_H_rr
  { 2, OperandInfo47 },  // Inst #264 = ABS_rr
  { 3, OperandInfo46 },  // Inst #265 = ADDC_rc
  { 3, OperandInfo45 },  // Inst #266 = ADDC_rr
  { 3, OperandInfo48 },  // Inst #267 = ADDIH_A_rlc
  { 3, OperandInfo46 },  // Inst #268 = ADDIH_rlc
  { 3, OperandInfo46 },  // Inst #269 = ADDI_rlc
  { 3, OperandInfo49 },  // Inst #270 = ADDSC_AT_rr
  { 3, OperandInfo50 },  // Inst #271 = ADDSC_AT_rr_v110
  { 4, OperandInfo51 },  // Inst #272 = ADDSC_A_rr
  { 4, OperandInfo52 },  // Inst #273 = ADDSC_A_rr_v110
  { 3, OperandInfo48 },  // Inst #274 = ADDSC_A_srrs
  { 3, OperandInfo53 },  // Inst #275 = ADDSC_A_srrs_v110
  { 3, OperandInfo45 },  // Inst #276 = ADDS_BU_rr_v110
  { 3, OperandInfo45 },  // Inst #277 = ADDS_B_rr
  { 3, OperandInfo45 },  // Inst #278 = ADDS_H
  { 3, OperandInfo45 },  // Inst #279 = ADDS_HU
  { 3, OperandInfo45 },  // Inst #280 = ADDS_U
  { 3, OperandInfo46 },  // Inst #281 = ADDS_U_rc
  { 3, OperandInfo46 },  // Inst #282 = ADDS_rc
  { 3, OperandInfo45 },  // Inst #283 = ADDS_rr
  { 2, OperandInfo47 },  // Inst #284 = ADDS_srr
  { 3, OperandInfo46 },  // Inst #285 = ADDX_rc
  { 3, OperandInfo45 },  // Inst #286 = ADDX_rr
  { 3, OperandInfo54 },  // Inst #287 = ADD_A_rr
  { 2, OperandInfo55 },  // Inst #288 = ADD_A_src
  { 2, OperandInfo56 },  // Inst #289 = ADD_A_srr
  { 3, OperandInfo45 },  // Inst #290 = ADD_B_rr
  { 4, OperandInfo57 },  // Inst #291 = ADD_F_rrr
  { 3, OperandInfo45 },  // Inst #292 = ADD_H_rr
  { 3, OperandInfo46 },  // Inst #293 = ADD_rc
  { 3, OperandInfo45 },  // Inst #294 = ADD_rr
  { 2, OperandInfo58 },  // Inst #295 = ADD_src
  { 2, OperandInfo58 },  // Inst #296 = ADD_src_15a
  { 2, OperandInfo58 },  // Inst #297 = ADD_src_a15
  { 2, OperandInfo47 },  // Inst #298 = ADD_srr
  { 2, OperandInfo47 },  // Inst #299 = ADD_srr_15a
  { 2, OperandInfo47 },  // Inst #300 = ADD_srr_a15
  { 5, OperandInfo59 },  // Inst #301 = ANDN_T
  { 3, OperandInfo46 },  // Inst #302 = ANDN_rc
  { 3, OperandInfo45 },  // Inst #303 = ANDN_rr
  { 5, OperandInfo59 },  // Inst #304 = AND_ANDN_T
  { 5, OperandInfo59 },  // Inst #305 = AND_AND_T
  { 3, OperandInfo46 },  // Inst #306 = AND_EQ_rc
  { 3, OperandInfo45 },  // Inst #307 = AND_EQ_rr
  { 3, OperandInfo46 },  // Inst #308 = AND_GE_U_rc
  { 3, OperandInfo45 },  // Inst #309 = AND_GE_U_rr
  { 3, OperandInfo46 },  // Inst #310 = AND_GE_rc
  { 3, OperandInfo45 },  // Inst #311 = AND_GE_rr
  { 3, OperandInfo46 },  // Inst #312 = AND_LT_U_rc
  { 3, OperandInfo45 },  // Inst #313 = AND_LT_U_rr
  { 3, OperandInfo46 },  // Inst #314 = AND_LT_rc
  { 3, OperandInfo45 },  // Inst #315 = AND_LT_rr
  { 3, OperandInfo46 },  // Inst #316 = AND_NE_rc
  { 3, OperandInfo45 },  // Inst #317 = AND_NE_rr
  { 5, OperandInfo59 },  // Inst #318 = AND_NOR_T
  { 5, OperandInfo59 },  // Inst #319 = AND_OR_T
  { 5, OperandInfo59 },  // Inst #320 = AND_T
  { 3, OperandInfo46 },  // Inst #321 = AND_rc
  { 3, OperandInfo45 },  // Inst #322 = AND_rr
  { 1, OperandInfo2 },  // Inst #323 = AND_sc
  { 1, OperandInfo2 },  // Inst #324 = AND_sc_v110
  { 2, OperandInfo47 },  // Inst #325 = AND_srr
  { 2, OperandInfo47 },  // Inst #326 = AND_srr_v110
  { 1, OperandInfo2 },  // Inst #327 = BISR_rc
  { 1, OperandInfo2 },  // Inst #328 = BISR_rc_v161
  { 1, OperandInfo2 },  // Inst #329 = BISR_sc
  { 1, OperandInfo2 },  // Inst #330 = BISR_sc_v110
  { 3, OperandInfo45 },  // Inst #331 = BMERGAE_rr_v110
  { 3, OperandInfo45 },  // Inst #332 = BMERGE_rr
  { 2, OperandInfo60 },  // Inst #333 = BSPLIT_rr
  { 2, OperandInfo60 },  // Inst #334 = BSPLIT_rr_v110
  { 2, OperandInfo55 },  // Inst #335 = CACHEA_I_bo_bso
  { 2, OperandInfo61 },  // Inst #336 = CACHEA_I_bo_c
  { 2, OperandInfo55 },  // Inst #337 = CACHEA_I_bo_pos
  { 2, OperandInfo55 },  // Inst #338 = CACHEA_I_bo_pre
  { 1, OperandInfo62 },  // Inst #339 = CACHEA_I_bo_r
  { 2, OperandInfo55 },  // Inst #340 = CACHEA_WI_bo_bso
  { 2, OperandInfo61 },  // Inst #341 = CACHEA_WI_bo_c
  { 2, OperandInfo55 },  // Inst #342 = CACHEA_WI_bo_pos
  { 2, OperandInfo55 },  // Inst #343 = CACHEA_WI_bo_pre
  { 1, OperandInfo62 },  // Inst #344 = CACHEA_WI_bo_r
  { 2, OperandInfo55 },  // Inst #345 = CACHEA_W_bo_bso
  { 2, OperandInfo61 },  // Inst #346 = CACHEA_W_bo_c
  { 2, OperandInfo55 },  // Inst #347 = CACHEA_W_bo_pos
  { 2, OperandInfo55 },  // Inst #348 = CACHEA_W_bo_pre
  { 1, OperandInfo62 },  // Inst #349 = CACHEA_W_bo_r
  { 2, OperandInfo55 },  // Inst #350 = CACHEI_I_bo_bso
  { 2, OperandInfo55 },  // Inst #351 = CACHEI_I_bo_pos
  { 2, OperandInfo55 },  // Inst #352 = CACHEI_I_bo_pre
  { 2, OperandInfo55 },  // Inst #353 = CACHEI_WI_bo_bso
  { 2, OperandInfo55 },  // Inst #354 = CACHEI_WI_bo_pos
  { 2, OperandInfo55 },  // Inst #355 = CACHEI_WI_bo_pre
  { 2, OperandInfo55 },  // Inst #356 = CACHEI_W_bo_bso
  { 2, OperandInfo55 },  // Inst #357 = CACHEI_W_bo_pos
  { 2, OperandInfo55 },  // Inst #358 = CACHEI_W_bo_pre
  { 4, OperandInfo52 },  // Inst #359 = CADDN_A_rcr_v110
  { 4, OperandInfo63 },  // Inst #360 = CADDN_A_rrr_v110
  { 4, OperandInfo64 },  // Inst #361 = CADDN_rcr
  { 4, OperandInfo57 },  // Inst #362 = CADDN_rrr
  { 2, OperandInfo58 },  // Inst #363 = CADDN_src
  { 2, OperandInfo47 },  // Inst #364 = CADDN_srr_v110
  { 4, OperandInfo52 },  // Inst #365 = CADD_A_rcr_v110
  { 4, OperandInfo63 },  // Inst #366 = CADD_A_rrr_v110
  { 4, OperandInfo64 },  // Inst #367 = CADD_rcr
  { 4, OperandInfo57 },  // Inst #368 = CADD_rrr
  { 2, OperandInfo58 },  // Inst #369 = CADD_src
  { 2, OperandInfo47 },  // Inst #370 = CADD_srr_v110
  { 1, OperandInfo2 },  // Inst #371 = CALLA_b
  { 1, OperandInfo65 },  // Inst #372 = CALLI_rr
  { 1, OperandInfo65 },  // Inst #373 = CALLI_rr_v110
  { 1, OperandInfo2 },  // Inst #374 = CALL_b
  { 1, OperandInfo2 },  // Inst #375 = CALL_sb
  { 2, OperandInfo47 },  // Inst #376 = CLO_B_rr_v110
  { 2, OperandInfo47 },  // Inst #377 = CLO_H_rr
  { 2, OperandInfo47 },  // Inst #378 = CLO_rr
  { 2, OperandInfo47 },  // Inst #379 = CLS_B_rr_v110
  { 2, OperandInfo47 },  // Inst #380 = CLS_H_rr
  { 2, OperandInfo47 },  // Inst #381 = CLS_rr
  { 2, OperandInfo47 },  // Inst #382 = CLZ_B_rr_v110
  { 2, OperandInfo47 },  // Inst #383 = CLZ_H_rr
  { 2, OperandInfo47 },  // Inst #384 = CLZ_rr
  { 2, OperandInfo58 },  // Inst #385 = CMOVN_src
  { 2, OperandInfo47 },  // Inst #386 = CMOVN_srr
  { 2, OperandInfo58 },  // Inst #387 = CMOV_src
  { 2, OperandInfo47 },  // Inst #388 = CMOV_srr
  { 3, OperandInfo66 },  // Inst #389 = CMPSWAP_W_bo_bso
  { 3, OperandInfo67 },  // Inst #390 = CMPSWAP_W_bo_c
  { 3, OperandInfo66 },  // Inst #391 = CMPSWAP_W_bo_pos
  { 3, OperandInfo66 },  // Inst #392 = CMPSWAP_W_bo_pre
  { 2, OperandInfo68 },  // Inst #393 = CMPSWAP_W_bo_r
  { 3, OperandInfo45 },  // Inst #394 = CMP_F_rr
  { 3, OperandInfo45 },  // Inst #395 = CRC32B_W_rr
  { 3, OperandInfo45 },  // Inst #396 = CRC32L_W_rr
  { 3, OperandInfo45 },  // Inst #397 = CRC32_B_rr
  { 4, OperandInfo57 },  // Inst #398 = CRCN_rrr
  { 4, OperandInfo63 },  // Inst #399 = CSUBN_A__rrr_v110
  { 4, OperandInfo57 },  // Inst #400 = CSUBN_rrr
  { 4, OperandInfo63 },  // Inst #401 = CSUB_A__rrr_v110
  { 4, OperandInfo57 },  // Inst #402 = CSUB_rrr
  { 0, 0 },  // Inst #403 = DEBUG_sr
  { 0, 0 },  // Inst #404 = DEBUG_sys
  { 5, OperandInfo69 },  // Inst #405 = DEXTR_rrpw
  { 4, OperandInfo57 },  // Inst #406 = DEXTR_rrrr
  { 4, OperandInfo70 },  // Inst #407 = DIFSC_A_rr_v110
  { 0, 0 },  // Inst #408 = DISABLE_sys
  { 1, OperandInfo71 },  // Inst #409 = DISABLE_sys_1
  { 3, OperandInfo45 },  // Inst #410 = DIV_F_rr
  { 3, OperandInfo72 },  // Inst #411 = DIV_U_rr
  { 3, OperandInfo72 },  // Inst #412 = DIV_rr
  { 0, 0 },  // Inst #413 = DSYNC_sys
  { 4, OperandInfo73 },  // Inst #414 = DVADJ_rrr
  { 4, OperandInfo73 },  // Inst #415 = DVADJ_rrr_v110
  { 2, OperandInfo60 },  // Inst #416 = DVADJ_srr_v110
  { 3, OperandInfo72 },  // Inst #417 = DVINIT_BU_rr
  { 3, OperandInfo72 },  // Inst #418 = DVINIT_BU_rr_v110
  { 3, OperandInfo72 },  // Inst #419 = DVINIT_B_rr
  { 3, OperandInfo72 },  // Inst #420 = DVINIT_B_rr_v110
  { 3, OperandInfo72 },  // Inst #421 = DVINIT_HU_rr
  { 3, OperandInfo72 },  // Inst #422 = DVINIT_HU_rr_v110
  { 3, OperandInfo72 },  // Inst #423 = DVINIT_H_rr
  { 3, OperandInfo72 },  // Inst #424 = DVINIT_H_rr_v110
  { 3, OperandInfo72 },  // Inst #425 = DVINIT_U_rr
  { 3, OperandInfo72 },  // Inst #426 = DVINIT_U_rr_v110
  { 3, OperandInfo72 },  // Inst #427 = DVINIT_rr
  { 3, OperandInfo72 },  // Inst #428 = DVINIT_rr_v110
  { 4, OperandInfo73 },  // Inst #429 = DVSTEP_U_rrr
  { 4, OperandInfo73 },  // Inst #430 = DVSTEP_U_rrrv110
  { 2, OperandInfo60 },  // Inst #431 = DVSTEP_Uv110
  { 4, OperandInfo73 },  // Inst #432 = DVSTEP_rrr
  { 4, OperandInfo73 },  // Inst #433 = DVSTEP_rrrv110
  { 2, OperandInfo60 },  // Inst #434 = DVSTEPv110
  { 0, 0 },  // Inst #435 = ENABLE_sys
  { 3, OperandInfo46 },  // Inst #436 = EQANY_B_rc
  { 3, OperandInfo45 },  // Inst #437 = EQANY_B_rr
  { 3, OperandInfo46 },  // Inst #438 = EQANY_H_rc
  { 3, OperandInfo45 },  // Inst #439 = EQANY_H_rr
  { 2, OperandInfo74 },  // Inst #440 = EQZ_A_rr
  { 3, OperandInfo75 },  // Inst #441 = EQ_A_rr
  { 3, OperandInfo45 },  // Inst #442 = EQ_B_rr
  { 3, OperandInfo45 },  // Inst #443 = EQ_H_rr
  { 3, OperandInfo45 },  // Inst #444 = EQ_W_rr
  { 3, OperandInfo46 },  // Inst #445 = EQ_rc
  { 3, OperandInfo45 },  // Inst #446 = EQ_rr
  { 2, OperandInfo58 },  // Inst #447 = EQ_src
  { 2, OperandInfo47 },  // Inst #448 = EQ_srr
  { 5, OperandInfo69 },  // Inst #449 = EXTR_U_rrpw
  { 3, OperandInfo76 },  // Inst #450 = EXTR_U_rrrr
  { 5, OperandInfo77 },  // Inst #451 = EXTR_U_rrrw
  { 5, OperandInfo69 },  // Inst #452 = EXTR_rrpw
  { 3, OperandInfo76 },  // Inst #453 = EXTR_rrrr
  { 5, OperandInfo77 },  // Inst #454 = EXTR_rrrw
  { 1, OperandInfo2 },  // Inst #455 = FCALLA_b
  { 1, OperandInfo65 },  // Inst #456 = FCALLA_i
  { 1, OperandInfo2 },  // Inst #457 = FCALL_b
  { 0, 0 },  // Inst #458 = FRET_sr
  { 0, 0 },  // Inst #459 = FRET_sys
  { 2, OperandInfo47 },  // Inst #460 = FTOHP_rr
  { 2, OperandInfo47 },  // Inst #461 = FTOIZ_rr
  { 2, OperandInfo47 },  // Inst #462 = FTOI_rr
  { 3, OperandInfo45 },  // Inst #463 = FTOQ31Z_rr
  { 3, OperandInfo45 },  // Inst #464 = FTOQ31_rr
  { 2, OperandInfo47 },  // Inst #465 = FTOUZ_rr
  { 2, OperandInfo47 },  // Inst #466 = FTOU_rr
  { 3, OperandInfo75 },  // Inst #467 = GE_A_rr
  { 3, OperandInfo46 },  // Inst #468 = GE_U_rc
  { 3, OperandInfo45 },  // Inst #469 = GE_U_rr
  { 3, OperandInfo46 },  // Inst #470 = GE_rc
  { 3, OperandInfo45 },  // Inst #471 = GE_rr
  { 2, OperandInfo47 },  // Inst #472 = HPTOF_rr
  { 5, OperandInfo78 },  // Inst #473 = IMASK_rcpw
  { 5, OperandInfo79 },  // Inst #474 = IMASK_rcrw
  { 5, OperandInfo79 },  // Inst #475 = IMASK_rrpw
  { 5, OperandInfo80 },  // Inst #476 = IMASK_rrrw
  { 5, OperandInfo81 },  // Inst #477 = INSERT_rcpw
  { 4, OperandInfo82 },  // Inst #478 = INSERT_rcrr
  { 5, OperandInfo69 },  // Inst #479 = INSERT_rcrw
  { 5, OperandInfo69 },  // Inst #480 = INSERT_rrpw
  { 4, OperandInfo83 },  // Inst #481 = INSERT_rrrr
  { 5, OperandInfo77 },  // Inst #482 = INSERT_rrrw
  { 5, OperandInfo59 },  // Inst #483 = INSN_T
  { 5, OperandInfo59 },  // Inst #484 = INS_T
  { 0, 0 },  // Inst #485 = ISYNC_sys
  { 2, OperandInfo47 },  // Inst #486 = ITOF_rr
  { 4, OperandInfo73 },  // Inst #487 = IXMAX_U_rrr
  { 4, OperandInfo73 },  // Inst #488 = IXMAX_rrr
  { 4, OperandInfo73 },  // Inst #489 = IXMIN_U_rrr
  { 4, OperandInfo73 },  // Inst #490 = IXMIN_rrr
  { 1, OperandInfo2 },  // Inst #491 = JA_b
  { 3, OperandInfo48 },  // Inst #492 = JEQ_A_brr
  { 3, OperandInfo84 },  // Inst #493 = JEQ_brc
  { 3, OperandInfo46 },  // Inst #494 = JEQ_brr
  { 2, OperandInfo7 },  // Inst #495 = JEQ_sbc1
  { 2, OperandInfo7 },  // Inst #496 = JEQ_sbc2
  { 2, OperandInfo7 },  // Inst #497 = JEQ_sbc_v110
  { 2, OperandInfo58 },  // Inst #498 = JEQ_sbr1
  { 2, OperandInfo58 },  // Inst #499 = JEQ_sbr2
  { 2, OperandInfo58 },  // Inst #500 = JEQ_sbr_v110
  { 2, OperandInfo58 },  // Inst #501 = JGEZ_sbr
  { 2, OperandInfo58 },  // Inst #502 = JGEZ_sbr_v110
  { 3, OperandInfo84 },  // Inst #503 = JGE_U_brc
  { 3, OperandInfo46 },  // Inst #504 = JGE_U_brr
  { 3, OperandInfo84 },  // Inst #505 = JGE_brc
  { 3, OperandInfo46 },  // Inst #506 = JGE_brr
  { 2, OperandInfo58 },  // Inst #507 = JGTZ_sbr
  { 2, OperandInfo58 },  // Inst #508 = JGTZ_sbr_v110
  { 1, OperandInfo65 },  // Inst #509 = JI_rr
  { 1, OperandInfo65 },  // Inst #510 = JI_rr_v110
  { 1, OperandInfo65 },  // Inst #511 = JI_sbr_v110
  { 1, OperandInfo65 },  // Inst #512 = JI_sr
  { 1, OperandInfo2 },  // Inst #513 = JLA_b
  { 2, OperandInfo58 },  // Inst #514 = JLEZ_sbr
  { 2, OperandInfo58 },  // Inst #515 = JLEZ_sbr_v110
  { 1, OperandInfo65 },  // Inst #516 = JLI_rr
  { 1, OperandInfo65 },  // Inst #517 = JLI_rr_v110
  { 2, OperandInfo58 },  // Inst #518 = JLTZ_sbr
  { 2, OperandInfo58 },  // Inst #519 = JLTZ_sbr_v110
  { 3, OperandInfo84 },  // Inst #520 = JLT_U_brc
  { 3, OperandInfo46 },  // Inst #521 = JLT_U_brr
  { 3, OperandInfo84 },  // Inst #522 = JLT_brc
  { 3, OperandInfo46 },  // Inst #523 = JLT_brr
  { 1, OperandInfo2 },  // Inst #524 = JL_b
  { 3, OperandInfo84 },  // Inst #525 = JNED_brc
  { 3, OperandInfo46 },  // Inst #526 = JNED_brr
  { 3, OperandInfo84 },  // Inst #527 = JNEI_brc
  { 3, OperandInfo46 },  // Inst #528 = JNEI_brr
  { 3, OperandInfo48 },  // Inst #529 = JNE_A_brr
  { 3, OperandInfo84 },  // Inst #530 = JNE_brc
  { 3, OperandInfo46 },  // Inst #531 = JNE_brr
  { 2, OperandInfo7 },  // Inst #532 = JNE_sbc1
  { 2, OperandInfo7 },  // Inst #533 = JNE_sbc2
  { 2, OperandInfo7 },  // Inst #534 = JNE_sbc_v110
  { 2, OperandInfo58 },  // Inst #535 = JNE_sbr1
  { 2, OperandInfo58 },  // Inst #536 = JNE_sbr2
  { 2, OperandInfo58 },  // Inst #537 = JNE_sbr_v110
  { 2, OperandInfo55 },  // Inst #538 = JNZ_A_brr
  { 2, OperandInfo55 },  // Inst #539 = JNZ_A_sbr
  { 3, OperandInfo85 },  // Inst #540 = JNZ_T_brn
  { 2, OperandInfo86 },  // Inst #541 = JNZ_T_sbrn
  { 2, OperandInfo86 },  // Inst #542 = JNZ_T_sbrn_v110
  { 1, OperandInfo2 },  // Inst #543 = JNZ_sb
  { 1, OperandInfo2 },  // Inst #544 = JNZ_sb_v110
  { 2, OperandInfo58 },  // Inst #545 = JNZ_sbr
  { 2, OperandInfo58 },  // Inst #546 = JNZ_sbr_v110
  { 2, OperandInfo55 },  // Inst #547 = JZ_A_brr
  { 2, OperandInfo55 },  // Inst #548 = JZ_A_sbr
  { 3, OperandInfo85 },  // Inst #549 = JZ_T_brn
  { 2, OperandInfo86 },  // Inst #550 = JZ_T_sbrn
  { 2, OperandInfo86 },  // Inst #551 = JZ_T_sbrn_v110
  { 1, OperandInfo2 },  // Inst #552 = JZ_sb
  { 1, OperandInfo2 },  // Inst #553 = JZ_sb_v110
  { 2, OperandInfo58 },  // Inst #554 = JZ_sbr
  { 2, OperandInfo58 },  // Inst #555 = JZ_sbr_v110
  { 1, OperandInfo2 },  // Inst #556 = J_b
  { 1, OperandInfo2 },  // Inst #557 = J_sb
  { 1, OperandInfo2 },  // Inst #558 = J_sb_v110
  { 1, OperandInfo2 },  // Inst #559 = LDLCX_abs
  { 2, OperandInfo55 },  // Inst #560 = LDLCX_bo_bso
  { 2, OperandInfo87 },  // Inst #561 = LDMST_abs
  { 3, OperandInfo66 },  // Inst #562 = LDMST_bo_bso
  { 3, OperandInfo67 },  // Inst #563 = LDMST_bo_c
  { 3, OperandInfo66 },  // Inst #564 = LDMST_bo_pos
  { 3, OperandInfo66 },  // Inst #565 = LDMST_bo_pre
  { 2, OperandInfo68 },  // Inst #566 = LDMST_bo_r
  { 1, OperandInfo2 },  // Inst #567 = LDUCX_abs
  { 2, OperandInfo55 },  // Inst #568 = LDUCX_bo_bso
  { 2, OperandInfo55 },  // Inst #569 = LD_A_abs
  { 3, OperandInfo48 },  // Inst #570 = LD_A_bo_bso
  { 3, OperandInfo88 },  // Inst #571 = LD_A_bo_c
  { 3, OperandInfo48 },  // Inst #572 = LD_A_bo_pos
  { 3, OperandInfo48 },  // Inst #573 = LD_A_bo_pre
  { 2, OperandInfo89 },  // Inst #574 = LD_A_bo_r
  { 3, OperandInfo48 },  // Inst #575 = LD_A_bol
  { 1, OperandInfo2 },  // Inst #576 = LD_A_sc
  { 2, OperandInfo56 },  // Inst #577 = LD_A_slr
  { 2, OperandInfo56 },  // Inst #578 = LD_A_slr_post
  { 2, OperandInfo56 },  // Inst #579 = LD_A_slr_post_v110
  { 2, OperandInfo56 },  // Inst #580 = LD_A_slr_v110
  { 2, OperandInfo55 },  // Inst #581 = LD_A_slro
  { 2, OperandInfo55 },  // Inst #582 = LD_A_slro_v110
  { 2, OperandInfo55 },  // Inst #583 = LD_A_sro
  { 2, OperandInfo55 },  // Inst #584 = LD_A_sro_v110
  { 2, OperandInfo58 },  // Inst #585 = LD_BU_abs
  { 3, OperandInfo90 },  // Inst #586 = LD_BU_bo_bso
  { 3, OperandInfo91 },  // Inst #587 = LD_BU_bo_c
  { 3, OperandInfo90 },  // Inst #588 = LD_BU_bo_pos
  { 3, OperandInfo90 },  // Inst #589 = LD_BU_bo_pre
  { 2, OperandInfo92 },  // Inst #590 = LD_BU_bo_r
  { 3, OperandInfo90 },  // Inst #591 = LD_BU_bol
  { 2, OperandInfo74 },  // Inst #592 = LD_BU_slr
  { 2, OperandInfo74 },  // Inst #593 = LD_BU_slr_post
  { 2, OperandInfo74 },  // Inst #594 = LD_BU_slr_post_v110
  { 2, OperandInfo74 },  // Inst #595 = LD_BU_slr_v110
  { 2, OperandInfo58 },  // Inst #596 = LD_BU_slro
  { 2, OperandInfo58 },  // Inst #597 = LD_BU_slro_v110
  { 2, OperandInfo55 },  // Inst #598 = LD_BU_sro
  { 2, OperandInfo55 },  // Inst #599 = LD_BU_sro_v110
  { 2, OperandInfo58 },  // Inst #600 = LD_B_abs
  { 3, OperandInfo90 },  // Inst #601 = LD_B_bo_bso
  { 3, OperandInfo91 },  // Inst #602 = LD_B_bo_c
  { 3, OperandInfo90 },  // Inst #603 = LD_B_bo_pos
  { 3, OperandInfo90 },  // Inst #604 = LD_B_bo_pre
  { 2, OperandInfo92 },  // Inst #605 = LD_B_bo_r
  { 3, OperandInfo90 },  // Inst #606 = LD_B_bol
  { 2, OperandInfo74 },  // Inst #607 = LD_B_slr_post_v110
  { 2, OperandInfo74 },  // Inst #608 = LD_B_slr_v110
  { 2, OperandInfo58 },  // Inst #609 = LD_B_slro_v110
  { 2, OperandInfo55 },  // Inst #610 = LD_B_sro_v110
  { 2, OperandInfo61 },  // Inst #611 = LD_DA_abs
  { 3, OperandInfo93 },  // Inst #612 = LD_DA_bo_bso
  { 3, OperandInfo94 },  // Inst #613 = LD_DA_bo_c
  { 3, OperandInfo93 },  // Inst #614 = LD_DA_bo_pos
  { 3, OperandInfo93 },  // Inst #615 = LD_DA_bo_pre
  { 2, OperandInfo95 },  // Inst #616 = LD_DA_bo_r
  { 2, OperandInfo87 },  // Inst #617 = LD_D_abs
  { 3, OperandInfo66 },  // Inst #618 = LD_D_bo_bso
  { 3, OperandInfo67 },  // Inst #619 = LD_D_bo_c
  { 3, OperandInfo66 },  // Inst #620 = LD_D_bo_pos
  { 3, OperandInfo66 },  // Inst #621 = LD_D_bo_pre
  { 2, OperandInfo68 },  // Inst #622 = LD_D_bo_r
  { 2, OperandInfo58 },  // Inst #623 = LD_HU_abs
  { 3, OperandInfo90 },  // Inst #624 = LD_HU_bo_bso
  { 3, OperandInfo91 },  // Inst #625 = LD_HU_bo_c
  { 3, OperandInfo90 },  // Inst #626 = LD_HU_bo_pos
  { 3, OperandInfo90 },  // Inst #627 = LD_HU_bo_pre
  { 2, OperandInfo92 },  // Inst #628 = LD_HU_bo_r
  { 3, OperandInfo90 },  // Inst #629 = LD_HU_bol
  { 2, OperandInfo58 },  // Inst #630 = LD_H_abs
  { 3, OperandInfo90 },  // Inst #631 = LD_H_bo_bso
  { 3, OperandInfo91 },  // Inst #632 = LD_H_bo_c
  { 3, OperandInfo90 },  // Inst #633 = LD_H_bo_pos
  { 3, OperandInfo90 },  // Inst #634 = LD_H_bo_pre
  { 2, OperandInfo92 },  // Inst #635 = LD_H_bo_r
  { 3, OperandInfo90 },  // Inst #636 = LD_H_bol
  { 2, OperandInfo74 },  // Inst #637 = LD_H_slr
  { 2, OperandInfo74 },  // Inst #638 = LD_H_slr_post
  { 2, OperandInfo74 },  // Inst #639 = LD_H_slr_post_v110
  { 2, OperandInfo74 },  // Inst #640 = LD_H_slr_v110
  { 2, OperandInfo58 },  // Inst #641 = LD_H_slro
  { 2, OperandInfo58 },  // Inst #642 = LD_H_slro_v110
  { 2, OperandInfo55 },  // Inst #643 = LD_H_sro
  { 2, OperandInfo55 },  // Inst #644 = LD_H_sro_v110
  { 2, OperandInfo58 },  // Inst #645 = LD_Q_abs
  { 3, OperandInfo90 },  // Inst #646 = LD_Q_bo_bso
  { 3, OperandInfo91 },  // Inst #647 = LD_Q_bo_c
  { 3, OperandInfo90 },  // Inst #648 = LD_Q_bo_pos
  { 3, OperandInfo90 },  // Inst #649 = LD_Q_bo_pre
  { 2, OperandInfo92 },  // Inst #650 = LD_Q_bo_r
  { 2, OperandInfo58 },  // Inst #651 = LD_W_abs
  { 3, OperandInfo90 },  // Inst #652 = LD_W_bo_bso
  { 3, OperandInfo91 },  // Inst #653 = LD_W_bo_c
  { 3, OperandInfo90 },  // Inst #654 = LD_W_bo_pos
  { 3, OperandInfo90 },  // Inst #655 = LD_W_bo_pre
  { 2, OperandInfo92 },  // Inst #656 = LD_W_bo_r
  { 3, OperandInfo90 },  // Inst #657 = LD_W_bol
  { 1, OperandInfo2 },  // Inst #658 = LD_W_sc
  { 2, OperandInfo74 },  // Inst #659 = LD_W_slr
  { 2, OperandInfo74 },  // Inst #660 = LD_W_slr_post
  { 2, OperandInfo74 },  // Inst #661 = LD_W_slr_post_v110
  { 2, OperandInfo74 },  // Inst #662 = LD_W_slr_v110
  { 2, OperandInfo58 },  // Inst #663 = LD_W_slro
  { 2, OperandInfo58 },  // Inst #664 = LD_W_slro_v110
  { 2, OperandInfo55 },  // Inst #665 = LD_W_sro
  { 2, OperandInfo55 },  // Inst #666 = LD_W_sro_v110
  { 2, OperandInfo55 },  // Inst #667 = LEA_abs
  { 3, OperandInfo48 },  // Inst #668 = LEA_bo_bso
  { 3, OperandInfo48 },  // Inst #669 = LEA_bol
  { 2, OperandInfo55 },  // Inst #670 = LHA_abs
  { 1, OperandInfo2 },  // Inst #671 = LOOPU_brr
  { 2, OperandInfo55 },  // Inst #672 = LOOP_brr
  { 2, OperandInfo55 },  // Inst #673 = LOOP_sbr
  { 3, OperandInfo75 },  // Inst #674 = LT_A_rr
  { 3, OperandInfo45 },  // Inst #675 = LT_B
  { 3, OperandInfo45 },  // Inst #676 = LT_BU
  { 3, OperandInfo45 },  // Inst #677 = LT_H
  { 3, OperandInfo45 },  // Inst #678 = LT_HU
  { 3, OperandInfo46 },  // Inst #679 = LT_U_rc
  { 3, OperandInfo45 },  // Inst #680 = LT_U_rr
  { 2, OperandInfo58 },  // Inst #681 = LT_U_srcv110
  { 2, OperandInfo47 },  // Inst #682 = LT_U_srrv110
  { 3, OperandInfo45 },  // Inst #683 = LT_W
  { 3, OperandInfo45 },  // Inst #684 = LT_WU
  { 3, OperandInfo46 },  // Inst #685 = LT_rc
  { 3, OperandInfo45 },  // Inst #686 = LT_rr
  { 2, OperandInfo58 },  // Inst #687 = LT_src
  { 2, OperandInfo47 },  // Inst #688 = LT_srr
  { 5, OperandInfo96 },  // Inst #689 = MADDMS_H_rrr1_LL
  { 5, OperandInfo96 },  // Inst #690 = MADDMS_H_rrr1_LU
  { 5, OperandInfo96 },  // Inst #691 = MADDMS_H_rrr1_UL
  { 5, OperandInfo96 },  // Inst #692 = MADDMS_H_rrr1_UU
  { 4, OperandInfo97 },  // Inst #693 = MADDMS_U_rcr_v110
  { 4, OperandInfo73 },  // Inst #694 = MADDMS_U_rrr2_v110
  { 4, OperandInfo97 },  // Inst #695 = MADDMS_rcr_v110
  { 4, OperandInfo73 },  // Inst #696 = MADDMS_rrr2_v110
  { 5, OperandInfo96 },  // Inst #697 = MADDM_H_rrr1_LL
  { 5, OperandInfo96 },  // Inst #698 = MADDM_H_rrr1_LU
  { 5, OperandInfo96 },  // Inst #699 = MADDM_H_rrr1_UL
  { 5, OperandInfo96 },  // Inst #700 = MADDM_H_rrr1_UU
  { 5, OperandInfo96 },  // Inst #701 = MADDM_H_rrr1_v110
  { 5, OperandInfo96 },  // Inst #702 = MADDM_Q_rrr1_v110
  { 4, OperandInfo97 },  // Inst #703 = MADDM_U_rcr_v110
  { 4, OperandInfo73 },  // Inst #704 = MADDM_U_rrr2_v110
  { 4, OperandInfo97 },  // Inst #705 = MADDM_rcr_v110
  { 4, OperandInfo73 },  // Inst #706 = MADDM_rrr2_v110
  { 5, OperandInfo98 },  // Inst #707 = MADDRS_H_rrr1_LL
  { 5, OperandInfo98 },  // Inst #708 = MADDRS_H_rrr1_LU
  { 5, OperandInfo98 },  // Inst #709 = MADDRS_H_rrr1_UL
  { 5, OperandInfo99 },  // Inst #710 = MADDRS_H_rrr1_UL_2
  { 5, OperandInfo98 },  // Inst #711 = MADDRS_H_rrr1_UU
  { 5, OperandInfo99 },  // Inst #712 = MADDRS_H_rrr1_v110
  { 5, OperandInfo98 },  // Inst #713 = MADDRS_Q_rrr1_L_L
  { 5, OperandInfo98 },  // Inst #714 = MADDRS_Q_rrr1_U_U
  { 5, OperandInfo98 },  // Inst #715 = MADDRS_Q_rrr1_v110
  { 5, OperandInfo98 },  // Inst #716 = MADDR_H_rrr1_LL
  { 5, OperandInfo98 },  // Inst #717 = MADDR_H_rrr1_LU
  { 5, OperandInfo98 },  // Inst #718 = MADDR_H_rrr1_UL
  { 5, OperandInfo99 },  // Inst #719 = MADDR_H_rrr1_UL_2
  { 5, OperandInfo98 },  // Inst #720 = MADDR_H_rrr1_UU
  { 5, OperandInfo99 },  // Inst #721 = MADDR_H_rrr1_v110
  { 5, OperandInfo98 },  // Inst #722 = MADDR_Q_rrr1_L_L
  { 5, OperandInfo98 },  // Inst #723 = MADDR_Q_rrr1_U_U
  { 5, OperandInfo98 },  // Inst #724 = MADDR_Q_rrr1_v110
  { 5, OperandInfo96 },  // Inst #725 = MADDSUMS_H_rrr1_LL
  { 5, OperandInfo96 },  // Inst #726 = MADDSUMS_H_rrr1_LU
  { 5, OperandInfo96 },  // Inst #727 = MADDSUMS_H_rrr1_UL
  { 5, OperandInfo96 },  // Inst #728 = MADDSUMS_H_rrr1_UU
  { 5, OperandInfo96 },  // Inst #729 = MADDSUM_H_rrr1_LL
  { 5, OperandInfo96 },  // Inst #730 = MADDSUM_H_rrr1_LU
  { 5, OperandInfo96 },  // Inst #731 = MADDSUM_H_rrr1_UL
  { 5, OperandInfo96 },  // Inst #732 = MADDSUM_H_rrr1_UU
  { 5, OperandInfo98 },  // Inst #733 = MADDSURS_H_rrr1_LL
  { 5, OperandInfo98 },  // Inst #734 = MADDSURS_H_rrr1_LU
  { 5, OperandInfo98 },  // Inst #735 = MADDSURS_H_rrr1_UL
  { 5, OperandInfo98 },  // Inst #736 = MADDSURS_H_rrr1_UU
  { 5, OperandInfo98 },  // Inst #737 = MADDSUR_H_rrr1_LL
  { 5, OperandInfo98 },  // Inst #738 = MADDSUR_H_rrr1_LU
  { 5, OperandInfo98 },  // Inst #739 = MADDSUR_H_rrr1_UL
  { 5, OperandInfo98 },  // Inst #740 = MADDSUR_H_rrr1_UU
  { 5, OperandInfo96 },  // Inst #741 = MADDSUS_H_rrr1_LL
  { 5, OperandInfo96 },  // Inst #742 = MADDSUS_H_rrr1_LU
  { 5, OperandInfo96 },  // Inst #743 = MADDSUS_H_rrr1_UL
  { 5, OperandInfo96 },  // Inst #744 = MADDSUS_H_rrr1_UU
  { 5, OperandInfo96 },  // Inst #745 = MADDSU_H_rrr1_LL
  { 5, OperandInfo96 },  // Inst #746 = MADDSU_H_rrr1_LU
  { 5, OperandInfo96 },  // Inst #747 = MADDSU_H_rrr1_UL
  { 5, OperandInfo96 },  // Inst #748 = MADDSU_H_rrr1_UU
  { 5, OperandInfo96 },  // Inst #749 = MADDS_H_rrr1_LL
  { 5, OperandInfo96 },  // Inst #750 = MADDS_H_rrr1_LU
  { 5, OperandInfo96 },  // Inst #751 = MADDS_H_rrr1_UL
  { 5, OperandInfo96 },  // Inst #752 = MADDS_H_rrr1_UU
  { 5, OperandInfo96 },  // Inst #753 = MADDS_H_rrr1_v110
  { 5, OperandInfo98 },  // Inst #754 = MADDS_Q_rrr1
  { 5, OperandInfo98 },  // Inst #755 = MADDS_Q_rrr1_L
  { 5, OperandInfo98 },  // Inst #756 = MADDS_Q_rrr1_L_L
  { 5, OperandInfo98 },  // Inst #757 = MADDS_Q_rrr1_U
  { 5, OperandInfo98 },  // Inst #758 = MADDS_Q_rrr1_UU2_v110
  { 5, OperandInfo98 },  // Inst #759 = MADDS_Q_rrr1_U_U
  { 5, OperandInfo96 },  // Inst #760 = MADDS_Q_rrr1_e
  { 5, OperandInfo96 },  // Inst #761 = MADDS_Q_rrr1_e_L
  { 5, OperandInfo96 },  // Inst #762 = MADDS_Q_rrr1_e_L_L
  { 5, OperandInfo96 },  // Inst #763 = MADDS_Q_rrr1_e_U
  { 5, OperandInfo96 },  // Inst #764 = MADDS_Q_rrr1_e_U_U
  { 4, OperandInfo64 },  // Inst #765 = MADDS_U_rcr
  { 4, OperandInfo97 },  // Inst #766 = MADDS_U_rcr_e
  { 4, OperandInfo57 },  // Inst #767 = MADDS_U_rrr2
  { 4, OperandInfo73 },  // Inst #768 = MADDS_U_rrr2_e
  { 4, OperandInfo64 },  // Inst #769 = MADDS_rcr
  { 4, OperandInfo97 },  // Inst #770 = MADDS_rcr_e
  { 4, OperandInfo57 },  // Inst #771 = MADDS_rrr2
  { 4, OperandInfo73 },  // Inst #772 = MADDS_rrr2_e
  { 4, OperandInfo57 },  // Inst #773 = MADD_F_rrr
  { 5, OperandInfo96 },  // Inst #774 = MADD_H_rrr1_LL
  { 5, OperandInfo96 },  // Inst #775 = MADD_H_rrr1_LU
  { 5, OperandInfo96 },  // Inst #776 = MADD_H_rrr1_UL
  { 5, OperandInfo96 },  // Inst #777 = MADD_H_rrr1_UU
  { 5, OperandInfo96 },  // Inst #778 = MADD_H_rrr1_v110
  { 5, OperandInfo98 },  // Inst #779 = MADD_Q_rrr1
  { 5, OperandInfo98 },  // Inst #780 = MADD_Q_rrr1_L
  { 5, OperandInfo98 },  // Inst #781 = MADD_Q_rrr1_L_L
  { 5, OperandInfo98 },  // Inst #782 = MADD_Q_rrr1_U
  { 5, OperandInfo98 },  // Inst #783 = MADD_Q_rrr1_UU2_v110
  { 5, OperandInfo98 },  // Inst #784 = MADD_Q_rrr1_U_U
  { 5, OperandInfo96 },  // Inst #785 = MADD_Q_rrr1_e
  { 5, OperandInfo96 },  // Inst #786 = MADD_Q_rrr1_e_L
  { 5, OperandInfo96 },  // Inst #787 = MADD_Q_rrr1_e_L_L
  { 5, OperandInfo96 },  // Inst #788 = MADD_Q_rrr1_e_U
  { 5, OperandInfo96 },  // Inst #789 = MADD_Q_rrr1_e_U_U
  { 4, OperandInfo97 },  // Inst #790 = MADD_U_rcr
  { 4, OperandInfo73 },  // Inst #791 = MADD_U_rrr2
  { 4, OperandInfo64 },  // Inst #792 = MADD_rcr
  { 4, OperandInfo97 },  // Inst #793 = MADD_rcr_e
  { 4, OperandInfo57 },  // Inst #794 = MADD_rrr2
  { 4, OperandInfo73 },  // Inst #795 = MADD_rrr2_e
  { 3, OperandInfo45 },  // Inst #796 = MAX_B
  { 3, OperandInfo45 },  // Inst #797 = MAX_BU
  { 3, OperandInfo45 },  // Inst #798 = MAX_H
  { 3, OperandInfo45 },  // Inst #799 = MAX_HU
  { 3, OperandInfo46 },  // Inst #800 = MAX_U_rc
  { 3, OperandInfo45 },  // Inst #801 = MAX_U_rr
  { 3, OperandInfo46 },  // Inst #802 = MAX_rc
  { 3, OperandInfo45 },  // Inst #803 = MAX_rr
  { 2, OperandInfo58 },  // Inst #804 = MFCR_rlc
  { 3, OperandInfo45 },  // Inst #805 = MIN_B
  { 3, OperandInfo45 },  // Inst #806 = MIN_BU
  { 3, OperandInfo45 },  // Inst #807 = MIN_H
  { 3, OperandInfo45 },  // Inst #808 = MIN_HU
  { 3, OperandInfo46 },  // Inst #809 = MIN_U_rc
  { 3, OperandInfo45 },  // Inst #810 = MIN_U_rr
  { 3, OperandInfo46 },  // Inst #811 = MIN_rc
  { 3, OperandInfo45 },  // Inst #812 = MIN_rr
  { 2, OperandInfo55 },  // Inst #813 = MOVH_A_rlc
  { 2, OperandInfo58 },  // Inst #814 = MOVH_rlc
  { 1, OperandInfo65 },  // Inst #815 = MOVZ_A_sr
  { 3, OperandInfo54 },  // Inst #816 = MOV_AA_rr
  { 2, OperandInfo56 },  // Inst #817 = MOV_AA_srr_srr
  { 2, OperandInfo56 },  // Inst #818 = MOV_AA_srr_srr_v110
  { 3, OperandInfo100 },  // Inst #819 = MOV_A_rr
  { 2, OperandInfo55 },  // Inst #820 = MOV_A_src
  { 2, OperandInfo101 },  // Inst #821 = MOV_A_srr
  { 2, OperandInfo101 },  // Inst #822 = MOV_A_srr_v110
  { 3, OperandInfo75 },  // Inst #823 = MOV_D_rr
  { 2, OperandInfo74 },  // Inst #824 = MOV_D_srr_srr
  { 2, OperandInfo74 },  // Inst #825 = MOV_D_srr_srr_v110
  { 2, OperandInfo58 },  // Inst #826 = MOV_U_rlc
  { 2, OperandInfo58 },  // Inst #827 = MOV_rlc
  { 2, OperandInfo87 },  // Inst #828 = MOV_rlc_e
  { 3, OperandInfo45 },  // Inst #829 = MOV_rr
  { 3, OperandInfo72 },  // Inst #830 = MOV_rr_e
  { 3, OperandInfo72 },  // Inst #831 = MOV_rr_eab
  { 1, OperandInfo2 },  // Inst #832 = MOV_sc
  { 1, OperandInfo2 },  // Inst #833 = MOV_sc_v110
  { 2, OperandInfo58 },  // Inst #834 = MOV_src
  { 2, OperandInfo87 },  // Inst #835 = MOV_src_e
  { 2, OperandInfo47 },  // Inst #836 = MOV_srr
  { 5, OperandInfo96 },  // Inst #837 = MSUBADMS_H_rrr1_LL
  { 5, OperandInfo96 },  // Inst #838 = MSUBADMS_H_rrr1_LU
  { 5, OperandInfo96 },  // Inst #839 = MSUBADMS_H_rrr1_UL
  { 5, OperandInfo96 },  // Inst #840 = MSUBADMS_H_rrr1_UU
  { 5, OperandInfo96 },  // Inst #841 = MSUBADM_H_rrr1_LL
  { 5, OperandInfo96 },  // Inst #842 = MSUBADM_H_rrr1_LU
  { 5, OperandInfo96 },  // Inst #843 = MSUBADM_H_rrr1_UL
  { 5, OperandInfo96 },  // Inst #844 = MSUBADM_H_rrr1_UU
  { 5, OperandInfo98 },  // Inst #845 = MSUBADRS_H_rrr1_LL
  { 5, OperandInfo98 },  // Inst #846 = MSUBADRS_H_rrr1_LU
  { 5, OperandInfo98 },  // Inst #847 = MSUBADRS_H_rrr1_UL
  { 5, OperandInfo98 },  // Inst #848 = MSUBADRS_H_rrr1_UU
  { 5, OperandInfo98 },  // Inst #849 = MSUBADRS_H_rrr1_v110
  { 5, OperandInfo98 },  // Inst #850 = MSUBADR_H_rrr1_LL
  { 5, OperandInfo98 },  // Inst #851 = MSUBADR_H_rrr1_LU
  { 5, OperandInfo98 },  // Inst #852 = MSUBADR_H_rrr1_UL
  { 5, OperandInfo98 },  // Inst #853 = MSUBADR_H_rrr1_UU
  { 5, OperandInfo98 },  // Inst #854 = MSUBADR_H_rrr1_v110
  { 5, OperandInfo96 },  // Inst #855 = MSUBADS_H_rrr1_LL
  { 5, OperandInfo96 },  // Inst #856 = MSUBADS_H_rrr1_LU
  { 5, OperandInfo96 },  // Inst #857 = MSUBADS_H_rrr1_UL
  { 5, OperandInfo96 },  // Inst #858 = MSUBADS_H_rrr1_UU
  { 5, OperandInfo96 },  // Inst #859 = MSUBAD_H_rrr1_LL
  { 5, OperandInfo96 },  // Inst #860 = MSUBAD_H_rrr1_LU
  { 5, OperandInfo96 },  // Inst #861 = MSUBAD_H_rrr1_UL
  { 5, OperandInfo96 },  // Inst #862 = MSUBAD_H_rrr1_UU
  { 5, OperandInfo96 },  // Inst #863 = MSUBMS_H_rrr1_LL
  { 5, OperandInfo96 },  // Inst #864 = MSUBMS_H_rrr1_LU
  { 5, OperandInfo96 },  // Inst #865 = MSUBMS_H_rrr1_UL
  { 5, OperandInfo96 },  // Inst #866 = MSUBMS_H_rrr1_UU
  { 4, OperandInfo97 },  // Inst #867 = MSUBMS_U_rcrv110
  { 4, OperandInfo73 },  // Inst #868 = MSUBMS_U_rrr2v110
  { 4, OperandInfo97 },  // Inst #869 = MSUBMS_rcrv110
  { 4, OperandInfo73 },  // Inst #870 = MSUBMS_rrr2v110
  { 5, OperandInfo96 },  // Inst #871 = MSUBM_H_rrr1_LL
  { 5, OperandInfo96 },  // Inst #872 = MSUBM_H_rrr1_LU
  { 5, OperandInfo96 },  // Inst #873 = MSUBM_H_rrr1_UL
  { 5, OperandInfo96 },  // Inst #874 = MSUBM_H_rrr1_UU
  { 5, OperandInfo96 },  // Inst #875 = MSUBM_H_rrr1_v110
  { 5, OperandInfo96 },  // Inst #876 = MSUBM_Q_rrr1_v110
  { 4, OperandInfo97 },  // Inst #877 = MSUBM_U_rcrv110
  { 4, OperandInfo73 },  // Inst #878 = MSUBM_U_rrr2v110
  { 4, OperandInfo97 },  // Inst #879 = MSUBM_rcrv110
  { 4, OperandInfo73 },  // Inst #880 = MSUBM_rrr2v110
  { 5, OperandInfo98 },  // Inst #881 = MSUBRS_H_rrr1_LL
  { 5, OperandInfo98 },  // Inst #882 = MSUBRS_H_rrr1_LU
  { 5, OperandInfo98 },  // Inst #883 = MSUBRS_H_rrr1_UL
  { 5, OperandInfo99 },  // Inst #884 = MSUBRS_H_rrr1_UL_2
  { 5, OperandInfo98 },  // Inst #885 = MSUBRS_H_rrr1_UU
  { 5, OperandInfo99 },  // Inst #886 = MSUBRS_H_rrr1_v110
  { 5, OperandInfo98 },  // Inst #887 = MSUBRS_Q_rrr1_L_L
  { 5, OperandInfo98 },  // Inst #888 = MSUBRS_Q_rrr1_U_U
  { 5, OperandInfo98 },  // Inst #889 = MSUBRS_Q_rrr1_v110
  { 5, OperandInfo98 },  // Inst #890 = MSUBR_H_rrr1_LL
  { 5, OperandInfo98 },  // Inst #891 = MSUBR_H_rrr1_LU
  { 5, OperandInfo98 },  // Inst #892 = MSUBR_H_rrr1_UL
  { 5, OperandInfo99 },  // Inst #893 = MSUBR_H_rrr1_UL_2
  { 5, OperandInfo98 },  // Inst #894 = MSUBR_H_rrr1_UU
  { 5, OperandInfo99 },  // Inst #895 = MSUBR_H_rrr1_v110
  { 5, OperandInfo98 },  // Inst #896 = MSUBR_Q_rrr1_L_L
  { 5, OperandInfo98 },  // Inst #897 = MSUBR_Q_rrr1_U_U
  { 5, OperandInfo98 },  // Inst #898 = MSUBR_Q_rrr1_v110
  { 5, OperandInfo96 },  // Inst #899 = MSUBS_H_rrr1_LL
  { 5, OperandInfo96 },  // Inst #900 = MSUBS_H_rrr1_LU
  { 5, OperandInfo96 },  // Inst #901 = MSUBS_H_rrr1_UL
  { 5, OperandInfo96 },  // Inst #902 = MSUBS_H_rrr1_UU
  { 5, OperandInfo96 },  // Inst #903 = MSUBS_H_rrr1_v110
  { 5, OperandInfo98 },  // Inst #904 = MSUBS_Q_rrr1
  { 5, OperandInfo98 },  // Inst #905 = MSUBS_Q_rrr1_L
  { 5, OperandInfo98 },  // Inst #906 = MSUBS_Q_rrr1_L_L
  { 5, OperandInfo98 },  // Inst #907 = MSUBS_Q_rrr1_U
  { 5, OperandInfo98 },  // Inst #908 = MSUBS_Q_rrr1_UU2_v110
  { 5, OperandInfo98 },  // Inst #909 = MSUBS_Q_rrr1_U_U
  { 5, OperandInfo96 },  // Inst #910 = MSUBS_Q_rrr1_e
  { 5, OperandInfo96 },  // Inst #911 = MSUBS_Q_rrr1_e_L
  { 5, OperandInfo96 },  // Inst #912 = MSUBS_Q_rrr1_e_L_L
  { 5, OperandInfo96 },  // Inst #913 = MSUBS_Q_rrr1_e_U
  { 5, OperandInfo96 },  // Inst #914 = MSUBS_Q_rrr1_e_U_U
  { 4, OperandInfo64 },  // Inst #915 = MSUBS_U_rcr
  { 4, OperandInfo97 },  // Inst #916 = MSUBS_U_rcr_e
  { 4, OperandInfo57 },  // Inst #917 = MSUBS_U_rrr2
  { 4, OperandInfo73 },  // Inst #918 = MSUBS_U_rrr2_e
  { 4, OperandInfo64 },  // Inst #919 = MSUBS_rcr
  { 4, OperandInfo97 },  // Inst #920 = MSUBS_rcr_e
  { 4, OperandInfo57 },  // Inst #921 = MSUBS_rrr2
  { 4, OperandInfo73 },  // Inst #922 = MSUBS_rrr2_e
  { 4, OperandInfo57 },  // Inst #923 = MSUB_F_rrr
  { 5, OperandInfo96 },  // Inst #924 = MSUB_H_rrr1_LL
  { 5, OperandInfo96 },  // Inst #925 = MSUB_H_rrr1_LU
  { 5, OperandInfo96 },  // Inst #926 = MSUB_H_rrr1_UL
  { 5, OperandInfo96 },  // Inst #927 = MSUB_H_rrr1_UU
  { 5, OperandInfo96 },  // Inst #928 = MSUB_H_rrr1_v110
  { 5, OperandInfo98 },  // Inst #929 = MSUB_Q_rrr1
  { 5, OperandInfo98 },  // Inst #930 = MSUB_Q_rrr1_L
  { 5, OperandInfo98 },  // Inst #931 = MSUB_Q_rrr1_L_L
  { 5, OperandInfo98 },  // Inst #932 = MSUB_Q_rrr1_U
  { 5, OperandInfo98 },  // Inst #933 = MSUB_Q_rrr1_UU2_v110
  { 5, OperandInfo98 },  // Inst #934 = MSUB_Q_rrr1_U_U
  { 5, OperandInfo96 },  // Inst #935 = MSUB_Q_rrr1_e
  { 5, OperandInfo96 },  // Inst #936 = MSUB_Q_rrr1_e_L
  { 5, OperandInfo96 },  // Inst #937 = MSUB_Q_rrr1_e_L_L
  { 5, OperandInfo96 },  // Inst #938 = MSUB_Q_rrr1_e_U
  { 5, OperandInfo96 },  // Inst #939 = MSUB_Q_rrr1_e_U_U
  { 4, OperandInfo97 },  // Inst #940 = MSUB_U_rcr
  { 4, OperandInfo73 },  // Inst #941 = MSUB_U_rrr2
  { 4, OperandInfo64 },  // Inst #942 = MSUB_rcr
  { 4, OperandInfo97 },  // Inst #943 = MSUB_rcr_e
  { 4, OperandInfo57 },  // Inst #944 = MSUB_rrr2
  { 4, OperandInfo73 },  // Inst #945 = MSUB_rrr2_e
  { 2, OperandInfo102 },  // Inst #946 = MTCR_rlc
  { 4, OperandInfo103 },  // Inst #947 = MULMS_H_rr1_LL2e
  { 4, OperandInfo103 },  // Inst #948 = MULMS_H_rr1_LU2e
  { 4, OperandInfo103 },  // Inst #949 = MULMS_H_rr1_UL2e
  { 4, OperandInfo103 },  // Inst #950 = MULMS_H_rr1_UU2e
  { 4, OperandInfo103 },  // Inst #951 = MULM_H_rr1_LL2e
  { 4, OperandInfo103 },  // Inst #952 = MULM_H_rr1_LU2e
  { 4, OperandInfo103 },  // Inst #953 = MULM_H_rr1_UL2e
  { 4, OperandInfo103 },  // Inst #954 = MULM_H_rr1_UU2e
  { 3, OperandInfo104 },  // Inst #955 = MULM_U_rc
  { 3, OperandInfo72 },  // Inst #956 = MULM_U_rr
  { 3, OperandInfo104 },  // Inst #957 = MULM_rc
  { 3, OperandInfo72 },  // Inst #958 = MULM_rr
  { 4, OperandInfo64 },  // Inst #959 = MULR_H_rr1_LL2e
  { 4, OperandInfo64 },  // Inst #960 = MULR_H_rr1_LU2e
  { 4, OperandInfo64 },  // Inst #961 = MULR_H_rr1_UL2e
  { 4, OperandInfo64 },  // Inst #962 = MULR_H_rr1_UU2e
  { 4, OperandInfo64 },  // Inst #963 = MULR_H_rr_v110
  { 4, OperandInfo64 },  // Inst #964 = MULR_Q_rr1_2LL
  { 4, OperandInfo64 },  // Inst #965 = MULR_Q_rr1_2UU
  { 4, OperandInfo64 },  // Inst #966 = MULR_Q_rr_v110
  { 3, OperandInfo46 },  // Inst #967 = MULS_U_rc
  { 3, OperandInfo45 },  // Inst #968 = MULS_U_rr2
  { 3, OperandInfo45 },  // Inst #969 = MULS_U_rr_v110
  { 3, OperandInfo46 },  // Inst #970 = MULS_rc
  { 3, OperandInfo45 },  // Inst #971 = MULS_rr2
  { 3, OperandInfo45 },  // Inst #972 = MULS_rr_v110
  { 3, OperandInfo45 },  // Inst #973 = MUL_F_rrr
  { 4, OperandInfo103 },  // Inst #974 = MUL_H_rr1_LL2e
  { 4, OperandInfo103 },  // Inst #975 = MUL_H_rr1_LU2e
  { 4, OperandInfo103 },  // Inst #976 = MUL_H_rr1_UL2e
  { 4, OperandInfo103 },  // Inst #977 = MUL_H_rr1_UU2e
  { 4, OperandInfo103 },  // Inst #978 = MUL_H_rr_v110
  { 4, OperandInfo64 },  // Inst #979 = MUL_Q_rr1_2
  { 4, OperandInfo64 },  // Inst #980 = MUL_Q_rr1_2LL
  { 4, OperandInfo64 },  // Inst #981 = MUL_Q_rr1_2UU
  { 4, OperandInfo64 },  // Inst #982 = MUL_Q_rr1_2_L
  { 4, OperandInfo103 },  // Inst #983 = MUL_Q_rr1_2_Le
  { 4, OperandInfo64 },  // Inst #984 = MUL_Q_rr1_2_U
  { 4, OperandInfo103 },  // Inst #985 = MUL_Q_rr1_2_Ue
  { 4, OperandInfo103 },  // Inst #986 = MUL_Q_rr1_2__e
  { 4, OperandInfo64 },  // Inst #987 = MUL_Q_rr_v110
  { 3, OperandInfo104 },  // Inst #988 = MUL_U_rc
  { 3, OperandInfo72 },  // Inst #989 = MUL_U_rr2
  { 3, OperandInfo46 },  // Inst #990 = MUL_rc
  { 3, OperandInfo104 },  // Inst #991 = MUL_rc_e
  { 3, OperandInfo45 },  // Inst #992 = MUL_rr2
  { 3, OperandInfo72 },  // Inst #993 = MUL_rr2_e
  { 3, OperandInfo45 },  // Inst #994 = MUL_rr_v110
  { 2, OperandInfo47 },  // Inst #995 = MUL_srr
  { 5, OperandInfo59 },  // Inst #996 = NAND_T
  { 3, OperandInfo46 },  // Inst #997 = NAND_rc
  { 3, OperandInfo45 },  // Inst #998 = NAND_rr
  { 2, OperandInfo74 },  // Inst #999 = NEZ_A
  { 3, OperandInfo75 },  // Inst #1000 = NE_A
  { 3, OperandInfo46 },  // Inst #1001 = NE_rc
  { 3, OperandInfo45 },  // Inst #1002 = NE_rr
  { 0, 0 },  // Inst #1003 = NOP_sr
  { 0, 0 },  // Inst #1004 = NOP_sys
  { 5, OperandInfo59 },  // Inst #1005 = NOR_T
  { 3, OperandInfo46 },  // Inst #1006 = NOR_rc
  { 3, OperandInfo45 },  // Inst #1007 = NOR_rr
  { 1, OperandInfo71 },  // Inst #1008 = NOR_sr
  { 1, OperandInfo71 },  // Inst #1009 = NOR_sr_v110
  { 1, OperandInfo71 },  // Inst #1010 = NOT_sr_v162
  { 5, OperandInfo59 },  // Inst #1011 = ORN_T
  { 3, OperandInfo46 },  // Inst #1012 = ORN_rc
  { 3, OperandInfo45 },  // Inst #1013 = ORN_rr
  { 5, OperandInfo59 },  // Inst #1014 = OR_ANDN_T
  { 5, OperandInfo59 },  // Inst #1015 = OR_AND_T
  { 3, OperandInfo46 },  // Inst #1016 = OR_EQ_rc
  { 3, OperandInfo45 },  // Inst #1017 = OR_EQ_rr
  { 3, OperandInfo46 },  // Inst #1018 = OR_GE_U_rc
  { 3, OperandInfo45 },  // Inst #1019 = OR_GE_U_rr
  { 3, OperandInfo46 },  // Inst #1020 = OR_GE_rc
  { 3, OperandInfo45 },  // Inst #1021 = OR_GE_rr
  { 3, OperandInfo46 },  // Inst #1022 = OR_LT_U_rc
  { 3, OperandInfo45 },  // Inst #1023 = OR_LT_U_rr
  { 3, OperandInfo46 },  // Inst #1024 = OR_LT_rc
  { 3, OperandInfo45 },  // Inst #1025 = OR_LT_rr
  { 3, OperandInfo46 },  // Inst #1026 = OR_NE_rc
  { 3, OperandInfo45 },  // Inst #1027 = OR_NE_rr
  { 5, OperandInfo59 },  // Inst #1028 = OR_NOR_T
  { 5, OperandInfo59 },  // Inst #1029 = OR_OR_T
  { 5, OperandInfo59 },  // Inst #1030 = OR_T
  { 3, OperandInfo46 },  // Inst #1031 = OR_rc
  { 3, OperandInfo45 },  // Inst #1032 = OR_rr
  { 1, OperandInfo2 },  // Inst #1033 = OR_sc
  { 1, OperandInfo2 },  // Inst #1034 = OR_sc_v110
  { 2, OperandInfo47 },  // Inst #1035 = OR_srr
  { 2, OperandInfo47 },  // Inst #1036 = OR_srr_v110
  { 4, OperandInfo83 },  // Inst #1037 = PACK_rrr
  { 2, OperandInfo47 },  // Inst #1038 = PARITY_rr
  { 2, OperandInfo47 },  // Inst #1039 = PARITY_rr_v110
  { 2, OperandInfo47 },  // Inst #1040 = POPCNT_W_rr
  { 3, OperandInfo45 },  // Inst #1041 = Q31TOF_rr
  { 2, OperandInfo47 },  // Inst #1042 = QSEED_F_rr
  { 1, OperandInfo71 },  // Inst #1043 = RESTORE_sys
  { 0, 0 },  // Inst #1044 = RET_sr
  { 0, 0 },  // Inst #1045 = RET_sys
  { 0, 0 },  // Inst #1046 = RET_sys_v110
  { 0, 0 },  // Inst #1047 = RFE_sr
  { 0, 0 },  // Inst #1048 = RFE_sys_sys
  { 0, 0 },  // Inst #1049 = RFE_sys_sys_v110
  { 0, 0 },  // Inst #1050 = RFM_sys
  { 0, 0 },  // Inst #1051 = RSLCX_sys
  { 0, 0 },  // Inst #1052 = RSTV_sys
  { 3, OperandInfo46 },  // Inst #1053 = RSUBS_U_rc
  { 3, OperandInfo46 },  // Inst #1054 = RSUBS_rc
  { 3, OperandInfo46 },  // Inst #1055 = RSUB_rc
  { 1, OperandInfo71 },  // Inst #1056 = RSUB_sr_sr
  { 1, OperandInfo71 },  // Inst #1057 = RSUB_sr_sr_v110
  { 2, OperandInfo47 },  // Inst #1058 = SAT_BU_rr
  { 1, OperandInfo71 },  // Inst #1059 = SAT_BU_sr
  { 1, OperandInfo71 },  // Inst #1060 = SAT_BU_sr_v110
  { 2, OperandInfo47 },  // Inst #1061 = SAT_B_rr
  { 1, OperandInfo71 },  // Inst #1062 = SAT_B_sr
  { 1, OperandInfo71 },  // Inst #1063 = SAT_B_sr_v110
  { 2, OperandInfo47 },  // Inst #1064 = SAT_HU_rr
  { 1, OperandInfo71 },  // Inst #1065 = SAT_HU_sr
  { 1, OperandInfo71 },  // Inst #1066 = SAT_HU_sr_v110
  { 2, OperandInfo47 },  // Inst #1067 = SAT_H_rr
  { 1, OperandInfo71 },  // Inst #1068 = SAT_H_sr
  { 1, OperandInfo71 },  // Inst #1069 = SAT_H_sr_v110
  { 4, OperandInfo52 },  // Inst #1070 = SELN_A_rcr_v110
  { 4, OperandInfo63 },  // Inst #1071 = SELN_A_rrr_v110
  { 4, OperandInfo64 },  // Inst #1072 = SELN_rcr
  { 4, OperandInfo57 },  // Inst #1073 = SELN_rrr
  { 4, OperandInfo52 },  // Inst #1074 = SEL_A_rcr_v110
  { 4, OperandInfo63 },  // Inst #1075 = SEL_A_rrr_v110
  { 4, OperandInfo64 },  // Inst #1076 = SEL_rcr
  { 4, OperandInfo57 },  // Inst #1077 = SEL_rrr
  { 3, OperandInfo46 },  // Inst #1078 = SHAS_rc
  { 3, OperandInfo45 },  // Inst #1079 = SHAS_rr
  { 3, OperandInfo46 },  // Inst #1080 = SHA_B_rc
  { 3, OperandInfo45 },  // Inst #1081 = SHA_B_rr
  { 3, OperandInfo46 },  // Inst #1082 = SHA_H_rc
  { 3, OperandInfo45 },  // Inst #1083 = SHA_H_rr
  { 3, OperandInfo46 },  // Inst #1084 = SHA_rc
  { 3, OperandInfo45 },  // Inst #1085 = SHA_rr
  { 2, OperandInfo58 },  // Inst #1086 = SHA_src
  { 2, OperandInfo58 },  // Inst #1087 = SHA_src_v110
  { 3, OperandInfo46 },  // Inst #1088 = SHUFFLE_rc
  { 5, OperandInfo59 },  // Inst #1089 = SH_ANDN_T
  { 5, OperandInfo59 },  // Inst #1090 = SH_AND_T
  { 3, OperandInfo46 },  // Inst #1091 = SH_B_rc
  { 3, OperandInfo45 },  // Inst #1092 = SH_B_rr
  { 3, OperandInfo46 },  // Inst #1093 = SH_EQ_rc
  { 3, OperandInfo45 },  // Inst #1094 = SH_EQ_rr
  { 3, OperandInfo46 },  // Inst #1095 = SH_GE_U_rc
  { 3, OperandInfo45 },  // Inst #1096 = SH_GE_U_rr
  { 3, OperandInfo46 },  // Inst #1097 = SH_GE_rc
  { 3, OperandInfo45 },  // Inst #1098 = SH_GE_rr
  { 3, OperandInfo46 },  // Inst #1099 = SH_H_rc
  { 3, OperandInfo45 },  // Inst #1100 = SH_H_rr
  { 3, OperandInfo46 },  // Inst #1101 = SH_LT_U_rc
  { 3, OperandInfo45 },  // Inst #1102 = SH_LT_U_rr
  { 3, OperandInfo46 },  // Inst #1103 = SH_LT_rc
  { 3, OperandInfo45 },  // Inst #1104 = SH_LT_rr
  { 5, OperandInfo59 },  // Inst #1105 = SH_NAND_T
  { 3, OperandInfo46 },  // Inst #1106 = SH_NE_rc
  { 3, OperandInfo45 },  // Inst #1107 = SH_NE_rr
  { 5, OperandInfo59 },  // Inst #1108 = SH_NOR_T
  { 5, OperandInfo59 },  // Inst #1109 = SH_ORN_T
  { 5, OperandInfo59 },  // Inst #1110 = SH_OR_T
  { 5, OperandInfo59 },  // Inst #1111 = SH_XNOR_T
  { 5, OperandInfo59 },  // Inst #1112 = SH_XOR_T
  { 3, OperandInfo46 },  // Inst #1113 = SH_rc
  { 3, OperandInfo45 },  // Inst #1114 = SH_rr
  { 2, OperandInfo58 },  // Inst #1115 = SH_src
  { 2, OperandInfo58 },  // Inst #1116 = SH_src_v110
  { 1, OperandInfo2 },  // Inst #1117 = STLCX_abs
  { 2, OperandInfo55 },  // Inst #1118 = STLCX_bo_bso
  { 1, OperandInfo2 },  // Inst #1119 = STUCX_abs
  { 2, OperandInfo55 },  // Inst #1120 = STUCX_bo_bso
  { 2, OperandInfo55 },  // Inst #1121 = ST_A_abs
  { 3, OperandInfo48 },  // Inst #1122 = ST_A_bo_bso
  { 3, OperandInfo93 },  // Inst #1123 = ST_A_bo_c
  { 3, OperandInfo48 },  // Inst #1124 = ST_A_bo_pos
  { 3, OperandInfo48 },  // Inst #1125 = ST_A_bo_pre
  { 2, OperandInfo105 },  // Inst #1126 = ST_A_bo_r
  { 3, OperandInfo48 },  // Inst #1127 = ST_A_bol
  { 1, OperandInfo2 },  // Inst #1128 = ST_A_sc
  { 2, OperandInfo55 },  // Inst #1129 = ST_A_sro
  { 2, OperandInfo55 },  // Inst #1130 = ST_A_sro_v110
  { 2, OperandInfo56 },  // Inst #1131 = ST_A_ssr
  { 2, OperandInfo56 },  // Inst #1132 = ST_A_ssr_pos
  { 2, OperandInfo56 },  // Inst #1133 = ST_A_ssr_pos_v110
  { 2, OperandInfo56 },  // Inst #1134 = ST_A_ssr_v110
  { 2, OperandInfo55 },  // Inst #1135 = ST_A_ssro
  { 2, OperandInfo55 },  // Inst #1136 = ST_A_ssro_v110
  { 2, OperandInfo58 },  // Inst #1137 = ST_B_abs
  { 3, OperandInfo90 },  // Inst #1138 = ST_B_bo_bso
  { 3, OperandInfo106 },  // Inst #1139 = ST_B_bo_c
  { 3, OperandInfo90 },  // Inst #1140 = ST_B_bo_pos
  { 3, OperandInfo90 },  // Inst #1141 = ST_B_bo_pre
  { 2, OperandInfo107 },  // Inst #1142 = ST_B_bo_r
  { 3, OperandInfo53 },  // Inst #1143 = ST_B_bol
  { 2, OperandInfo55 },  // Inst #1144 = ST_B_sro
  { 2, OperandInfo55 },  // Inst #1145 = ST_B_sro_v110
  { 2, OperandInfo101 },  // Inst #1146 = ST_B_ssr
  { 2, OperandInfo101 },  // Inst #1147 = ST_B_ssr_pos
  { 2, OperandInfo101 },  // Inst #1148 = ST_B_ssr_pos_v110
  { 2, OperandInfo101 },  // Inst #1149 = ST_B_ssr_v110
  { 2, OperandInfo58 },  // Inst #1150 = ST_B_ssro
  { 2, OperandInfo58 },  // Inst #1151 = ST_B_ssro_v110
  { 2, OperandInfo61 },  // Inst #1152 = ST_DA_abs
  { 3, OperandInfo93 },  // Inst #1153 = ST_DA_bo_bso
  { 3, OperandInfo94 },  // Inst #1154 = ST_DA_bo_c
  { 3, OperandInfo93 },  // Inst #1155 = ST_DA_bo_pos
  { 3, OperandInfo93 },  // Inst #1156 = ST_DA_bo_pre
  { 2, OperandInfo95 },  // Inst #1157 = ST_DA_bo_r
  { 2, OperandInfo87 },  // Inst #1158 = ST_D_abs
  { 3, OperandInfo66 },  // Inst #1159 = ST_D_bo_bso
  { 3, OperandInfo108 },  // Inst #1160 = ST_D_bo_c
  { 3, OperandInfo66 },  // Inst #1161 = ST_D_bo_pos
  { 3, OperandInfo66 },  // Inst #1162 = ST_D_bo_pre
  { 2, OperandInfo109 },  // Inst #1163 = ST_D_bo_r
  { 2, OperandInfo58 },  // Inst #1164 = ST_H_abs
  { 3, OperandInfo90 },  // Inst #1165 = ST_H_bo_bso
  { 3, OperandInfo106 },  // Inst #1166 = ST_H_bo_c
  { 3, OperandInfo90 },  // Inst #1167 = ST_H_bo_pos
  { 3, OperandInfo90 },  // Inst #1168 = ST_H_bo_pre
  { 2, OperandInfo107 },  // Inst #1169 = ST_H_bo_r
  { 3, OperandInfo53 },  // Inst #1170 = ST_H_bol
  { 2, OperandInfo55 },  // Inst #1171 = ST_H_sro
  { 2, OperandInfo55 },  // Inst #1172 = ST_H_sro_v110
  { 2, OperandInfo101 },  // Inst #1173 = ST_H_ssr
  { 2, OperandInfo101 },  // Inst #1174 = ST_H_ssr_pos
  { 2, OperandInfo101 },  // Inst #1175 = ST_H_ssr_pos_v110
  { 2, OperandInfo101 },  // Inst #1176 = ST_H_ssr_v110
  { 2, OperandInfo58 },  // Inst #1177 = ST_H_ssro
  { 2, OperandInfo58 },  // Inst #1178 = ST_H_ssro_v110
  { 2, OperandInfo58 },  // Inst #1179 = ST_Q_abs
  { 3, OperandInfo90 },  // Inst #1180 = ST_Q_bo_bso
  { 3, OperandInfo106 },  // Inst #1181 = ST_Q_bo_c
  { 3, OperandInfo90 },  // Inst #1182 = ST_Q_bo_pos
  { 3, OperandInfo90 },  // Inst #1183 = ST_Q_bo_pre
  { 2, OperandInfo107 },  // Inst #1184 = ST_Q_bo_r
  { 3, OperandInfo110 },  // Inst #1185 = ST_T
  { 2, OperandInfo58 },  // Inst #1186 = ST_W_abs
  { 3, OperandInfo90 },  // Inst #1187 = ST_W_bo_bso
  { 3, OperandInfo106 },  // Inst #1188 = ST_W_bo_c
  { 3, OperandInfo90 },  // Inst #1189 = ST_W_bo_pos
  { 3, OperandInfo90 },  // Inst #1190 = ST_W_bo_pre
  { 2, OperandInfo107 },  // Inst #1191 = ST_W_bo_r
  { 3, OperandInfo53 },  // Inst #1192 = ST_W_bol
  { 1, OperandInfo2 },  // Inst #1193 = ST_W_sc
  { 2, OperandInfo55 },  // Inst #1194 = ST_W_sro
  { 2, OperandInfo55 },  // Inst #1195 = ST_W_sro_v110
  { 2, OperandInfo101 },  // Inst #1196 = ST_W_ssr
  { 2, OperandInfo101 },  // Inst #1197 = ST_W_ssr_pos
  { 2, OperandInfo101 },  // Inst #1198 = ST_W_ssr_pos_v110
  { 2, OperandInfo101 },  // Inst #1199 = ST_W_ssr_v110
  { 2, OperandInfo58 },  // Inst #1200 = ST_W_ssro
  { 2, OperandInfo58 },  // Inst #1201 = ST_W_ssro_v110
  { 3, OperandInfo45 },  // Inst #1202 = SUBC_rr
  { 4, OperandInfo52 },  // Inst #1203 = SUBSC_A_rr
  { 3, OperandInfo45 },  // Inst #1204 = SUBS_BU_rr
  { 3, OperandInfo45 },  // Inst #1205 = SUBS_B_rr
  { 3, OperandInfo45 },  // Inst #1206 = SUBS_HU_rr
  { 3, OperandInfo45 },  // Inst #1207 = SUBS_H_rr
  { 3, OperandInfo45 },  // Inst #1208 = SUBS_U_rr
  { 3, OperandInfo45 },  // Inst #1209 = SUBS_rr
  { 2, OperandInfo47 },  // Inst #1210 = SUBS_srr
  { 3, OperandInfo45 },  // Inst #1211 = SUBX_rr
  { 3, OperandInfo54 },  // Inst #1212 = SUB_A_rr
  { 1, OperandInfo2 },  // Inst #1213 = SUB_A_sc
  { 1, OperandInfo2 },  // Inst #1214 = SUB_A_sc_v110
  { 3, OperandInfo45 },  // Inst #1215 = SUB_B_rr
  { 4, OperandInfo57 },  // Inst #1216 = SUB_F_rrr
  { 3, OperandInfo45 },  // Inst #1217 = SUB_H_rr
  { 3, OperandInfo45 },  // Inst #1218 = SUB_rr
  { 2, OperandInfo47 },  // Inst #1219 = SUB_srr
  { 2, OperandInfo47 },  // Inst #1220 = SUB_srr_15a
  { 2, OperandInfo47 },  // Inst #1221 = SUB_srr_a15
  { 0, 0 },  // Inst #1222 = SVLCX_sys
  { 3, OperandInfo66 },  // Inst #1223 = SWAPMSK_W_bo_bso
  { 3, OperandInfo108 },  // Inst #1224 = SWAPMSK_W_bo_c
  { 3, OperandInfo67 },  // Inst #1225 = SWAPMSK_W_bo_i
  { 3, OperandInfo66 },  // Inst #1226 = SWAPMSK_W_bo_pos
  { 3, OperandInfo66 },  // Inst #1227 = SWAPMSK_W_bo_pre
  { 2, OperandInfo109 },  // Inst #1228 = SWAPMSK_W_bo_r
  { 2, OperandInfo55 },  // Inst #1229 = SWAP_A_abs
  { 3, OperandInfo48 },  // Inst #1230 = SWAP_A_bo_bso
  { 3, OperandInfo93 },  // Inst #1231 = SWAP_A_bo_c
  { 3, OperandInfo48 },  // Inst #1232 = SWAP_A_bo_pos
  { 3, OperandInfo48 },  // Inst #1233 = SWAP_A_bo_pre
  { 2, OperandInfo105 },  // Inst #1234 = SWAP_A_bo_r
  { 2, OperandInfo58 },  // Inst #1235 = SWAP_W_abs
  { 3, OperandInfo90 },  // Inst #1236 = SWAP_W_bo_bso
  { 3, OperandInfo106 },  // Inst #1237 = SWAP_W_bo_c
  { 3, OperandInfo91 },  // Inst #1238 = SWAP_W_bo_i
  { 3, OperandInfo90 },  // Inst #1239 = SWAP_W_bo_pos
  { 3, OperandInfo90 },  // Inst #1240 = SWAP_W_bo_pre
  { 2, OperandInfo107 },  // Inst #1241 = SWAP_W_bo_r
  { 1, OperandInfo2 },  // Inst #1242 = SYSCALL_rc
  { 1, OperandInfo71 },  // Inst #1243 = TLBDEMAP_rr
  { 0, 0 },  // Inst #1244 = TLBFLUSH_A_rr
  { 0, 0 },  // Inst #1245 = TLBFLUSH_B_rr
  { 1, OperandInfo111 },  // Inst #1246 = TLBMAP_rr
  { 1, OperandInfo71 },  // Inst #1247 = TLBPROBE_A_rr
  { 1, OperandInfo71 },  // Inst #1248 = TLBPROBE_I_rr
  { 0, 0 },  // Inst #1249 = TRAPSV_sys
  { 0, 0 },  // Inst #1250 = TRAPV_sys
  { 2, OperandInfo60 },  // Inst #1251 = UNPACK_rr_rr
  { 2, OperandInfo60 },  // Inst #1252 = UNPACK_rr_rr_v110
  { 1, OperandInfo71 },  // Inst #1253 = UPDFL_rr
  { 2, OperandInfo47 },  // Inst #1254 = UTOF_rr
  { 0, 0 },  // Inst #1255 = WAIT_sys
  { 5, OperandInfo59 },  // Inst #1256 = XNOR_T
  { 3, OperandInfo46 },  // Inst #1257 = XNOR_rc
  { 3, OperandInfo45 },  // Inst #1258 = XNOR_rr
  { 3, OperandInfo46 },  // Inst #1259 = XOR_EQ_rc
  { 3, OperandInfo45 },  // Inst #1260 = XOR_EQ_rr
  { 3, OperandInfo46 },  // Inst #1261 = XOR_GE_U_rc
  { 3, OperandInfo45 },  // Inst #1262 = XOR_GE_U_rr
  { 3, OperandInfo46 },  // Inst #1263 = XOR_GE_rc
  { 3, OperandInfo45 },  // Inst #1264 = XOR_GE_rr
  { 3, OperandInfo46 },  // Inst #1265 = XOR_LT_U_rc
  { 3, OperandInfo45 },  // Inst #1266 = XOR_LT_U_rr
  { 3, OperandInfo46 },  // Inst #1267 = XOR_LT_rc
  { 3, OperandInfo45 },  // Inst #1268 = XOR_LT_rr
  { 3, OperandInfo46 },  // Inst #1269 = XOR_NE_rc
  { 3, OperandInfo45 },  // Inst #1270 = XOR_NE_rr
  { 5, OperandInfo59 },  // Inst #1271 = XOR_T
  { 3, OperandInfo46 },  // Inst #1272 = XOR_rc
  { 3, OperandInfo45 },  // Inst #1273 = XOR_rr
  { 2, OperandInfo47 },  // Inst #1274 = XOR_srr
};

#endif // GET_INSTRINFO_MC_DESC


